﻿using System;
using System.Collections.Generic;
using System.Linq;
using System.Text;
using System.Windows;
using System.Windows.Controls;
using System.Windows.Data;
using System.Windows.Documents;
using System.Windows.Input;
using System.Windows.Media;
using System.Windows.Media.Imaging;
using System.Windows.Navigation;
using System.Windows.Shapes;
using MindFusion.Charting.Wpf;
using System.Windows.Media.Effects;

namespace Demo
{
	/// <summary>
	/// Interaction logic for Axes.xaml
	/// </summary>
	public partial class Axes : UserControl
	{
		public Axes()
		{
			InitializeComponent();

			barChart.Title = "Fruit Sales";
            barChart.Y2Axes.Add(new Axis());


			//YAxisSettings
			List<string> list = new List<string>();
			for (int i = 0; i < 110; i++)
				list.Add((i * 10).ToString());

            barChart.YAxes[0].Labels = list;
			barChart.YAxes[0].LabelType = LabelType.CustomText;
            barChart.YAxes[0].CustomLabelPosition = CustomLabelPosition.AutoScalePoints;
            barChart.YAxes[0].MinValue = 0;
            barChart.YAxes[0].MaxValue = 100;
            barChart.YAxes[0].Interval = 10;
            barChart.YAxes[0].Title = "kilograms";
            barChart.YAxes[0].TitleRotationAngle = 270;
            barChart.YAxes[0].LabelOffset = 10;
            barChart.YAxes[0].TitleOffset = 10;

            barChart.GridFills.Add(Brushes.Transparent);
            barChart.Foreground = Brushes.White;

            barChart.XAxes[0].LabelStroke = Brushes.White;
            barChart.XAxes[0].TitleStroke = Brushes.White;
            barChart.XAxes[0].HorLabelAlignment = HorizontalAlignment.Center;

            barChart.YAxes[0].LabelStroke = Brushes.White;
            barChart.YAxes[0].TitleStroke = Brushes.White;
            barChart.YAxes[0].VertLabelAlignment = VerticalAlignment.Center;

            barChart.Y2Axes[0].LabelStroke = Brushes.White;
            barChart.Y2Axes[0].TitleStroke = Brushes.White;
            barChart.Y2Axes[0].VertLabelAlignment = VerticalAlignment.Center;



			//Y2AxisSettings
			list = new List<string>();
			for (int i = 0; i < 110; i++)
				list.Add(((i * 10) * 2.2).ToString());
			barChart.Y2Axes[0].Labels = list;
            barChart.Y2Axes[0].LabelType = LabelType.CustomText;
            barChart.Y2Axes[0].CustomLabelPosition = CustomLabelPosition.AutoScalePoints;
            barChart.Y2Axes[0].MinValue = 0;
            barChart.Y2Axes[0].MaxValue = 100;
            barChart.Y2Axes[0].Interval = 10;
            barChart.Y2Axes[0].Title = "pounds";
            barChart.Y2Axes[0].TitleRotationAngle = 270;
            barChart.Y2Axes[0].LabelOffset = 10;
            barChart.Y2Axes[0].TitleOffset = 10;



			//XAxisSettings
			barChart.XAxes[0].Labels = new string[] {
				"Jan",
				"Feb",
				"Mar",
				"Apr",
				"May",
				"Jun",
				"Jul",
				"Aug",
			};
            barChart.XAxes[0].LabelType = LabelType.CustomText;
            barChart.XAxes[0].MinValue = 0;
            barChart.XAxes[0].MaxValue = 8;
            barChart.XAxes[0].Title = "Months";
            barChart.XAxes[0].LabelOffset = 10;
            barChart.XAxes[0].TitleOffset = 10;



			//Series
			BarSeries series = new BarSeries();
			series.YData = new DoubleCollection() {
				82, 60, 91, 73, 13, 62, 33, 38,
			};
			series.XData = new DoubleCollection() {
				1, 2, 3, 4, 5, 6, 7, 8,
			};

            BrushCollection brushes = Utilities.GetGradientFills();
            for (int i = 0; i < 8; i++)
            {
                LinearGradientBrush b = brushes[i] as LinearGradientBrush;
                Color light = b.GradientStops[0].Color;
                Color dark = b.GradientStops[1].Color;
                VisualBrush brush = Utilities.CreateVisualBrush(
                    dark, light, new SolidColorBrush(dark), 4, Orientation.Vertical, 4);
                series.Fills.Add(brush);
            }
			//series.Fills = Utilities.GetGradientFills();
			//series.Strokes = Utilities.GetGradientStrokes();
            series.StrokeThickness = 0;
            series.Effect = new DropShadowEffect() { Opacity = 0.3, ShadowDepth = 3, };
			barChart.Series.Clear();
			barChart.Series.Add(series);

            Unloaded += new RoutedEventHandler(Axes_Unloaded);
		}

        void Axes_Unloaded(object sender, RoutedEventArgs e)
        {
            Root.SizeChanged -= new SizeChangedEventHandler(Border_SizeChanged);
            But1.SizeChanged -= new SizeChangedEventHandler(Border_SizeChanged);
            But2.SizeChanged -= new SizeChangedEventHandler(Border_SizeChanged);
            But3.SizeChanged -= new SizeChangedEventHandler(Border_SizeChanged);
        }      


		private void OnXAxisSettingsClick(object sender, RoutedEventArgs e)
		{
			AxisSettingsWindow w = new AxisSettingsWindow(barChart.XAxes[0]);
			w.Title = "XAxisSettings";
			w.ShowDialog();
		}

		private void OnYAxisSettingsClick(object sender, RoutedEventArgs e)
		{
			AxisSettingsWindow w = new AxisSettingsWindow(barChart.YAxes[0]);
			w.Title = "YAxisSettings";
			w.ShowDialog();
		}

		private void OnY2AxisSettingsClick(object sender, RoutedEventArgs e)
		{
			AxisSettingsWindow w = new AxisSettingsWindow(barChart.Y2Axes[0]);
			w.Title = "Y2AxisSettings";
			w.ShowDialog();
		}

        private void Border_SizeChanged(object sender, SizeChangedEventArgs e)
        {
            Window1.OnBackPanelSizeChanged(sender);
        }
	}
}
