﻿using System;
using System.Collections.Generic;
using System.Linq;
using System.Text;
using System.Windows;
using System.Windows.Controls;
using System.Windows.Data;
using System.Windows.Documents;
using System.Windows.Input;
using System.Windows.Media;
using System.Windows.Media.Imaging;
using System.Windows.Shapes;
using MindFusion.Charting.Wpf;

namespace Demo
{
	/// <summary>
	/// Interaction logic for AxisSettingsWindow.xaml
	/// </summary>
	public partial class AxisSettingsWindow : Window
	{
		public AxisSettingsWindow(Axis set)
		{
			InitializeComponent();
			GetSettings(set);
		}

		private void GetSettings(Axis original)
		{
			originalSettings = original;
			settings = new Axis();
			settings.MinValue = originalSettings.MinValue;
			settings.MaxValue = originalSettings.MaxValue;
			settings.Interval = originalSettings.Interval;
			settings.LabelType = originalSettings.LabelType;
			settings.LabelRotationAngle = originalSettings.LabelRotationAngle;
			settings.Title = originalSettings.Title;
			settings.TitleRotationAngle = originalSettings.TitleRotationAngle;
            settings.IntervalCount = originalSettings.IntervalCount;

			minValueBox.Text = settings.MinValue.ToString();
			maxValueBox.Text = settings.MaxValue.ToString();
			intervalBox.Text = settings.Interval.ToString();
            intervalCountBox.Text = settings.IntervalCount.ToString();
			if (settings.LabelType == LabelType.AutoScale)
				labelTypeBox.SelectedIndex = 0;
			if (settings.LabelType == LabelType.ChartData)
				labelTypeBox.SelectedIndex = 1;
			if (settings.LabelType == LabelType.CustomText)
				labelTypeBox.SelectedIndex = 2;
			if (settings.LabelType == LabelType.Empty)
				labelTypeBox.SelectedIndex = 3;
			if (settings.LabelType == LabelType.Percents)
				labelTypeBox.SelectedIndex = 4;
			labelRotationSlider.Value = settings.LabelRotationAngle;
			titleBox.Text = settings.Title;
			titleRotationSlider.Value = settings.TitleRotationAngle;
		}

		private void SetSettings()
		{
			originalSettings.MinValue = settings.MinValue;
			originalSettings.MaxValue = settings.MaxValue;
			originalSettings.Interval = settings.Interval;
			originalSettings.LabelType = settings.LabelType;
			originalSettings.LabelRotationAngle = settings.LabelRotationAngle;
			originalSettings.Title = settings.Title;
			originalSettings.TitleRotationAngle = settings.TitleRotationAngle;
            originalSettings.IntervalCount = settings.IntervalCount;
		}

		public Axis Settings
		{
			get { return settings; }
			set { settings = value; }
		}

		private void SetTextBox(TextBox box)
		{
			string s = box.Text;
			bool enter = false;
			for (int i = 0; i < s.Length; i++)
			{
				if (!char.IsDigit(s[i]) || i == 0 && s[i] == '-')
				{
					enter = true;
					break;
				}
			}

			if (enter)
			{
				if (box.Name == "minValueBox")
					box.Text = settings.MinValue.ToString();
				if (box.Name == "maxValueBox")
					box.Text = settings.MaxValue.ToString();
				if (box.Name == "intervalBox")
					box.Text = settings.Interval.ToString();
			}
			else if (box.Text != "")
			{
				if (box.Name == "minValueBox")
					settings.MinValue = double.Parse(box.Text);
				if (box.Name == "maxValueBox")
					settings.MaxValue = double.Parse(box.Text);
				if (box.Name == "intervalBox")
					settings.Interval = double.Parse(box.Text);
                if (box.Name == "intervalCountBox")
                    settings.IntervalCount = int.Parse(box.Text);
			}
		}

		private void OnMinValueTextChanged(object sender, TextChangedEventArgs e)
		{
			SetTextBox(sender as TextBox);
		}

		private void OnMaxValueTextChanged(object sender, TextChangedEventArgs e)
		{
			SetTextBox(sender as TextBox);
		}

		private void OnIntervalTextChanged(object sender, TextChangedEventArgs e)
		{
			SetTextBox(sender as TextBox);
		}

		

		private void labelRotationSlider_ValueChanged(object sender, RoutedPropertyChangedEventArgs<double> e)
		{
			settings.LabelRotationAngle = labelRotationSlider.Value;
		}

		private void titleRotationSlider_ValueChanged(object sender, RoutedPropertyChangedEventArgs<double> e)
		{
			settings.TitleRotationAngle = titleRotationSlider.Value;
		}

		private void titleBox_TextChanged(object sender, TextChangedEventArgs e)
		{
			settings.Title = titleBox.Text;
		}

		private void labelTypeBox_SelectionChanged(object sender, SelectionChangedEventArgs e)
		{
			if (labelTypeBox.SelectedIndex == 0)
				settings.LabelType = LabelType.AutoScale;
			if (labelTypeBox.SelectedIndex == 1)
				settings.LabelType = LabelType.ChartData;
			if (labelTypeBox.SelectedIndex == 2)
				settings.LabelType = LabelType.CustomText;
			if (labelTypeBox.SelectedIndex == 3)
				settings.LabelType = LabelType.Empty;
			if (labelTypeBox.SelectedIndex == 4)
				settings.LabelType = LabelType.Percents;
		}

		private void OnButtonOkClick(object sender, RoutedEventArgs e)
		{
			SetSettings();
			this.Close();
		}

		private void OnButtonCancelClick(object sender, RoutedEventArgs e)
		{
			this.Close();
		}

		private Axis settings;
        private Axis originalSettings;
	}
}
