﻿using System;
using System.Collections.Generic;
using System.Linq;
using System.Text;
using System.Windows;
using System.Windows.Controls;
using System.Windows.Data;
using System.Windows.Documents;
using System.Windows.Input;
using System.Windows.Media;
using System.Windows.Media.Imaging;
using System.Windows.Navigation;
using System.Windows.Shapes;
using MindFusion.Charting.Wpf;
using System.Windows.Media.Effects;

namespace Demo
{
	/// <summary>
	/// Interaction logic for BarChart.xaml
	/// </summary>
	public partial class BarChart : UserControl
	{
		private DoubleCollection xData;
		private DoubleCollection yData;
		private DoubleCollection progressData;
		private Random r = new Random();

		public BarChart()
		{
			InitializeComponent();

			


			Random r = new Random();
            xData = new DoubleCollection() { 1, 2, 3, 4, 5, 6, 7 };
            yData = new DoubleCollection() { 25, 20, 33, 36, 24, 15, 19 };
            progressData = new DoubleCollection() { 25, 20, 33, 36, 24, 15, 19 };
			List<string> labels = new List<string>() {
				"Monday", "Tuesday", "Wednesday", "Thursday", "Friday", "Saturday", "Sunday" 
			};



			barChart.GridType = GridType.Vertical;

			barChart.XAxes[0].Title = "";
            barChart.XAxes[0].LabelType = LabelType.AutoScale;
            barChart.XAxes[0].MinValue = 0;
            barChart.XAxes[0].MaxValue = 40;
            barChart.XAxes[0].Interval = 10;
            barChart.XAxes[0].LabelStroke = Brushes.White;
            barChart.XAxes[0].HorLabelAlignment = HorizontalAlignment.Center;


            barChart.YAxes[0].Title = "";
            barChart.YAxes[0].LabelType = LabelType.CustomText;
			barChart.YAxes[0].Labels = labels;
            barChart.YAxes[0].MinValue = 0;
            barChart.YAxes[0].MaxValue = 7;
            barChart.YAxes[0].Interval = 1;
            barChart.YAxes[0].LabelStroke = Brushes.White;
            barChart.YAxes[0].VertLabelAlignment = VerticalAlignment.Center;
			

			BarSeries series = new BarSeries();
            series.Effect = new DropShadowEffect() { Opacity = 0.5, ShadowDepth = 3, };
            
			series.XData = yData;
			series.YData = xData;


            BrushCollection col = Utilities.GetGradientFills(true);


            for (int i = 0; i < 8; i++)
            {
                LinearGradientBrush b = col[i] as LinearGradientBrush;
                Color light = b.GradientStops[0].Color;
                Color dark = b.GradientStops[1].Color;
                VisualBrush brush = Utilities.CreateVisualBrush(
                    dark, light, new SolidColorBrush(dark), 0, Orientation.Horizontal, 10);
                series.Fills.Add(brush);
                series.Strokes.Add(new SolidColorBrush(dark));
            }
            
			//series.Fills = Utilities.GetGradientFills(true);
			//series.Strokes = Utilities.GetGradientStrokes();
			series.Progress = progressData;
            barChart.BarType = BarType.Horizontal;

			series.StrokeThickness = 1;
			series.StrokeLineJoin = PenLineJoin.Round;
			barChart.Series.Clear();
			barChart.Series.Add(series);


            VisualBrush fb1 = Utilities.CreateVisualBrush(
                Colors.Gray, Colors.White, new SolidColorBrush(Colors.Gray), 0, Orientation.Vertical, 0);
            fb1.Opacity = 0.2;
            barChart.GridFills.Add(fb1);
		}

		private int index = 0;

		private void OnAddAnnotationClick(object sender, RoutedEventArgs e)
		{
			BarSeries series = barChart.Series[0] as BarSeries;
			Annotation annotation = new Annotation();
			annotation.Index = dayOfWeek.SelectedIndex;
			annotation.Label = "Annotation " + series.Annotations.Count.ToString();
			annotation.Value = yData[dayOfWeek.SelectedIndex] * value.Value;
			annotation.Size = 10.0;
			annotation.StrokeThickness = 2;
			if (index == 0)
			{
				annotation.AnnotationType = AnnotationType.Point;
				annotation.Stroke = Utilities.GetGradientStrokes()[dayOfWeek.SelectedIndex];
				annotation.Fill = Utilities.GetGradientFills()[dayOfWeek.SelectedIndex];
			}
			if (index == 1)
			{
				annotation.AnnotationType = AnnotationType.Stick;
				annotation.Stroke = Utilities.GetGradientStrokes()[dayOfWeek.SelectedIndex];
				annotation.Fill = Utilities.GetGradientStrokes()[dayOfWeek.SelectedIndex];
			}
			if (index == 2)
				annotation.AnnotationType = AnnotationType.Empty;
			index += 1;
			if (index > 2)
				index = 0;		
			series.Annotations.Add(annotation);
			barChart.UpdateChart();
		}

		private void removeAnnotation_Click(object sender, RoutedEventArgs e)
		{
			BarSeries series = barChart.Series[0] as BarSeries;
			if (series.Annotations.Count > 0)
				series.Annotations.Remove(series.Annotations[series.Annotations.Count - 1]);
			barChart.UpdateChart();
		}

		private void Slider_ValueChanged(object sender, RoutedPropertyChangedEventArgs<double> e)
		{
			if (progressData != null)
			{
                progressData[dayOfWeek.SelectedIndex] = progress.Value;
				barChart.UpdateChart();
			}
		}

		private void dayOfWeek_SelectionChanged(object sender, SelectionChangedEventArgs e)
		{
			if (progressData != null)
			{
				progress.Value = progressData[dayOfWeek.SelectedIndex] / yData[dayOfWeek.SelectedIndex];
			}
		}

        private void Border_SizeChanged(object sender, SizeChangedEventArgs e)
        {
            Window1.OnBackPanelSizeChanged(sender);
        }

        private void ComboBox_DropDownOpened(object sender, EventArgs e)
        {
            ((sender as ComboBox).Items[0] as ComboBoxItem).Visibility = Visibility.Collapsed;
        }

        private void ComboBox_DropDownClosed(object sender, EventArgs e)
        {
            ((sender as ComboBox).Items[0] as ComboBoxItem).Visibility = Visibility.Visible;
        }
	}
}
