﻿using System;
using System.Collections.Generic;
using System.Linq;
using System.Text;
using System.Windows;
using System.Windows.Controls;
using System.Windows.Data;
using System.Windows.Documents;
using System.Windows.Input;
using System.Windows.Media;
using System.Windows.Media.Imaging;
using System.Windows.Navigation;
using System.Windows.Shapes;
using MindFusion.Charting.Wpf;
using System.Windows.Media.Effects;
using System.Windows.Media.Animation;

namespace Demo
{
	/// <summary>
	/// Interaction logic for BarTypes.xaml
	/// </summary>
	public partial class BarTypes : UserControl
	{
		SalesList sales;
		DoubleCollection data;

        BrushCollection brushes = Utilities.GetGradientFills();
        BrushCollection strokes = Utilities.GetGradientStrokes();
        DropShadowEffect effect;

		public BarTypes()
		{
			InitializeComponent();
            effect = new DropShadowEffect() { Opacity = 0.3, ShadowDepth = 3, };
            effect.Freeze();


            _barChart.GridFills.Add(Brushes.Transparent);
            _barChart.XAxes[0].LabelStroke = Brushes.White;
            _barChart.YAxes[0].LabelStroke = Brushes.White;
            _barChart.XAxes[0].TitleStroke = Brushes.White;
            _barChart.YAxes[0].TitleStroke = Brushes.White;
            _barChart.YAxes[0].LabelFormat = "0.##";
            _barChart.XAxes[0].LabelFormat = "0.##";
            _barChart.YAxes[0].TitleOffset = 10;
            _barChart.YAxes[0].VertLabelAlignment = VerticalAlignment.Center;
            _barChart.YAxes[0].HorLabelAlignment = HorizontalAlignment.Left;
            _barChart.XAxes[0].VertLabelAlignment = VerticalAlignment.Bottom;
            _barChart.XAxes[0].HorLabelAlignment = HorizontalAlignment.Center;
            //_barChart.Effect = effect;

            //stackPanel.Effect = effect;

			_barChart.Title = "";
			sales = new SalesList();
			_barChart.DataSource = sales;

            data = new DoubleCollection() { 1, 2, 3, 4, 5, 6 };
			AddSingleVertSeries(BarType.Vertical);
			SetVertAxesSettings();              
		}     

		private void cbHorizontal_Checked(object sender, RoutedEventArgs e)
		{
			SetHorSettings();
		}

		private void cbHorizontal_Unchecked(object sender, RoutedEventArgs e)
		{
			SetVertSettings();
		}

		private void cbLineType_SelectionChanged(object sender, SelectionChangedEventArgs e)
		{
			if (cbHorizontal == null)
				return;
			if (cbHorizontal.IsChecked == true)
				SetHorSettings();
			else
				SetVertSettings();
		}

		private void SetVertSettings()
		{
			switch (cbBarType.SelectedIndex)
			{
				case 0:
					{
                        _barChart.BarType = BarType.Vertical;
						AddSingleVertSeries(BarType.Vertical);
						SetVertAxesSettings();
						break;
					}
				case 1:
					{
                        _barChart.BarType = BarType.Vertical;
						AddMultipleVertSeries(BarType.Vertical);
						SetVertAxesSettings();
						break;
					}
				case 2:
					{

                        _barChart.BarType = BarType.VerticalOverlay;
						AddMultipleVertSeries(BarType.VerticalOverlay);
						SetVertAxesSettings();
						break;
					}
				case 3:
					{
                        _barChart.BarType = BarType.VerticalStack;
						AddMultipleVertSeries(BarType.VerticalStack);
						SetVertAxesSettings();
						break;
					}
			}

			_barChart.UpdateChart();
		}

		private void SetHorSettings()
		{
			switch (cbBarType.SelectedIndex)
			{
				case 0:
					{
                        _barChart.BarType = BarType.Horizontal;
						AddSingleHorSeries(BarType.Horizontal);
						SetHorAxesSettings();
						break;
					}
				case 1:
					{
                        _barChart.BarType = BarType.Horizontal;
						AddMultipleHorSeries(BarType.Horizontal);
						SetHorAxesSettings();
						break;
					}
				case 2:
					{
                        _barChart.BarType = BarType.HorizontalOverlay;
						AddMultipleHorSeries(BarType.HorizontalOverlay);
						SetHorAxesSettings();
						break;
					}
				case 3:
					{
                        _barChart.BarType = BarType.HorizontalStack;
						AddMultipleHorSeries(BarType.HorizontalStack);
						SetHorAxesSettings();
						break;
					}
			}

			_barChart.UpdateChart();
		}

		private void AddSingleVertSeries(BarType barType)
		{
			_barChart.Series.Clear();
            BarSeries series1 = new BarSeries() { Fills = new BrushCollection(), Strokes = new BrushCollection() };
            series1.Effect = effect;
            _barChart.BarType = barType;
		
			series1.XData = data;
			series1.Title = "Profit";
			series1.YDataPath = "Profit";

            LinearGradientBrush b = brushes[brushes.Count - 1] as LinearGradientBrush;
            Color light = b.GradientStops[0].Color;
            Color dark = b.GradientStops[1].Color;

            for (int i = 0; i < 6; i++)
            {
                VisualBrush brush = Utilities.CreateVisualBrush(
                    dark, light, new SolidColorBrush(dark), 4, Orientation.Vertical, 10);
                series1.Fills.Add(brush);
            }
            series1.StrokeThickness = 0;
			//series1.Fills.Add(brushes[brushes.Count - 1]);
			//series1.Strokes.Add(strokes[brushes.Count - 1]);
			_barChart.Series.Add(series1);
		}

		private void AddSingleHorSeries(BarType barType)
		{
			_barChart.Series.Clear();
            BarSeries series1 = new BarSeries() { Fills = new BrushCollection(), Strokes = new BrushCollection() };
            series1.Effect = effect;
            _barChart.BarType = barType;
			series1.YData = data;
			series1.Title = "Profit";
			series1.XDataPath = "Profit";

            LinearGradientBrush b = brushes[brushes.Count - 1] as LinearGradientBrush;
            Color light = b.GradientStops[0].Color;
            Color dark = b.GradientStops[1].Color;

            for (int i = 0; i < 6; i++)
            {
                VisualBrush brush = Utilities.CreateVisualBrush(
                    dark, light, new SolidColorBrush(dark), 4, Orientation.Horizontal, 10);
                series1.Fills.Add(brush);
            }
            series1.StrokeThickness = 0;



			//series1.Fills.Add(brushes[brushes.Count - 1]);
			//series1.Strokes.Add(strokes[brushes.Count - 1]);
			_barChart.Series.Add(series1);
		}

		private void AddMultipleVertSeries(BarType barType)
		{
			_barChart.Series.Clear();

            BarSeries series1 = new BarSeries() { Fills = new BrushCollection(), Strokes = new BrushCollection() };
            series1.Effect = effect;
            _barChart.BarType = barType;
			series1.XData = data;
			series1.Title = "Profit";
			series1.YDataPath = "Profit";
			//series1.Fills.Add(brushes[brushes.Count - 1]);
			//series1.Strokes.Add(strokes[brushes.Count - 1]);

            LinearGradientBrush b = brushes[brushes.Count - 1] as LinearGradientBrush;
            Color light = b.GradientStops[0].Color;
            Color dark = b.GradientStops[1].Color;

            for (int i = 0; i < 6; i++)
            {
                VisualBrush brush = Utilities.CreateVisualBrush(
                    dark, light, new SolidColorBrush(dark), 4, Orientation.Vertical, 5);
                series1.Fills.Add(brush);
            }
            series1.StrokeThickness = 0;


            BarSeries series2 = new BarSeries() { Fills = new BrushCollection(), Strokes = new BrushCollection() };
            series2.Effect = effect;
			series2.XData = data;
            _barChart.BarType = barType;
			series2.Title = "Turnover";
			series2.YDataPath = "Turnover";
			//series2.Fills.Add(brushes[brushes.Count - 2]);
			//series2.Strokes.Add(strokes[brushes.Count - 2]);

            b = brushes[brushes.Count - 2] as LinearGradientBrush;
            light = b.GradientStops[0].Color;
            dark = b.GradientStops[1].Color;

            for (int i = 0; i < 6; i++)
            {
                VisualBrush brush = Utilities.CreateVisualBrush(
                    dark, light, new SolidColorBrush(dark), 4, Orientation.Vertical, 5);
                series2.Fills.Add(brush);
            }
            series2.StrokeThickness = 0;

            BarSeries series3 = new BarSeries() { Fills = new BrushCollection(), Strokes = new BrushCollection() };
            series3.Effect = effect;
            _barChart.BarType = barType;
			series3.XData = data;
			series3.Title = "Margin";
			series3.YDataPath = "Margin";
			//series3.Fills.Add(brushes[3]);
			//series3.Strokes.Add(strokes[3]);

            b = brushes[3] as LinearGradientBrush;
            light = b.GradientStops[0].Color;
            dark = b.GradientStops[1].Color;

            for (int i = 0; i < 6; i++)
            {
                VisualBrush brush = Utilities.CreateVisualBrush(
                    dark, light, new SolidColorBrush(dark), 4, Orientation.Vertical, 5);
                series3.Fills.Add(brush);
            }
            series3.StrokeThickness = 0;

			_barChart.Series.Add(series1);
			_barChart.Series.Add(series2);
			_barChart.Series.Add(series3);
		}

		private void AddMultipleHorSeries(BarType barType)
		{
			_barChart.Series.Clear();

            BarSeries series1 = new BarSeries() { Fills = new BrushCollection(), Strokes = new BrushCollection() };
            series1.Effect = effect;
            _barChart.BarType = barType;
			series1.YData = data;
			series1.Title = "Profit";
			series1.XDataPath = "Profit";
			//series1.Fills.Add(brushes[brushes.Count - 1]);
			//series1.Strokes.Add(strokes[brushes.Count - 1]);
            LinearGradientBrush b = brushes[brushes.Count - 1] as LinearGradientBrush;
            Color light = b.GradientStops[0].Color;
            Color dark = b.GradientStops[1].Color;

            for (int i = 0; i < 6; i++)
            {
                VisualBrush brush = Utilities.CreateVisualBrush(
                    dark, light, new SolidColorBrush(dark), 4, Orientation.Horizontal, 3);
                series1.Fills.Add(brush);
            }
            series1.StrokeThickness = 0;



            BarSeries series2 = new BarSeries() { Fills = new BrushCollection(), Strokes = new BrushCollection() };
            series2.Effect = effect;
            _barChart.BarType = barType;
			series2.Title = "Turnover";
			series2.XDataPath = "Turnover";
			series2.YData = data;
			//series2.Fills.Add(brushes[brushes.Count - 2]);
			//series2.Strokes.Add(strokes[brushes.Count - 2]);
            b = brushes[brushes.Count - 2] as LinearGradientBrush;
            light = b.GradientStops[0].Color;
            dark = b.GradientStops[1].Color;

            for (int i = 0; i < 6; i++)
            {
                VisualBrush brush = Utilities.CreateVisualBrush(
                    dark, light, new SolidColorBrush(dark), 4, Orientation.Horizontal, 3);
                series2.Fills.Add(brush);
            }
            series2.StrokeThickness = 0;

            BarSeries series3 = new BarSeries() { Fills = new BrushCollection(), Strokes = new BrushCollection() };
            series3.Effect = effect;
            _barChart.BarType = barType;
			series3.Title = "Margin";
			series3.YData = data;
			series3.XDataPath = "Margin";
			//series3.Fills.Add(brushes[3]);
			//series3.Strokes.Add(strokes[3]);
            b = brushes[3] as LinearGradientBrush;
            light = b.GradientStops[0].Color;
            dark = b.GradientStops[1].Color;

            for (int i = 0; i < 6; i++)
            {
                VisualBrush brush = Utilities.CreateVisualBrush(
                    dark, light, new SolidColorBrush(dark), 4, Orientation.Horizontal, 3);
                series3.Fills.Add(brush);
            }
            series3.StrokeThickness = 0;


			_barChart.Series.Add(series1);
			_barChart.Series.Add(series2);
			_barChart.Series.Add(series3);

           
		}

		private void SetHorAxesSettings()
		{
			_barChart.XAxes[0].Interval = 50;
			_barChart.XAxes[0].Title = "Sales";
			_barChart.XAxes[0].LabelType = LabelType.AutoScale;

			_barChart.YAxes[0].LabelType = LabelType.CustomText;
			_barChart.YAxes[0].Interval = 1.0;
			_barChart.YAxes[0].Title = "Month";
			_barChart.YAxes[0].LabelPath = "Month";

            _barChart.GridType = GridType.Vertical;
		}

		private void SetVertAxesSettings()
		{
			_barChart.YAxes[0].Interval = 50;
            _barChart.YAxes[0].Title = "Sales";
            _barChart.YAxes[0].LabelType = LabelType.AutoScale;

            _barChart.XAxes[0].LabelType = LabelType.CustomText;
            _barChart.XAxes[0].Interval = 1.0;
            _barChart.XAxes[0].Title = "Month";
			_barChart.XAxes[0].LabelPath = "Month";

            _barChart.GridType = GridType.Horizontal;
		}

        private void Border_SizeChanged(object sender, SizeChangedEventArgs e)
        {
            Window1.OnBackPanelSizeChanged(sender);
        }       

        private void ComboBox_SizeChanged(object sender, SizeChangedEventArgs e)
        {
            Window1.OnBackPanelSizeChanged(sender);
        }

        private void ComboBox_DropDownOpened(object sender, EventArgs e)
        {
            ((sender as ComboBox).Items[0] as ComboBoxItem).Visibility = Visibility.Collapsed;
        }

        private void ComboBox_DropDownClosed(object sender, EventArgs e)
        {
            ((sender as ComboBox).Items[0] as ComboBoxItem).Visibility = Visibility.Visible;
        }

        private void Button_SizeChanged(object sender, SizeChangedEventArgs e)
        {
            Window1.OnBackPanelSizeChanged(sender);
        }
	}
}
