﻿using System;
using System.Collections.Generic;
using System.Linq;
using System.Text;
using System.Windows;
using System.Windows.Controls;
using System.Windows.Data;
using System.Windows.Documents;
using System.Windows.Input;
using System.Windows.Media;
using System.Windows.Media.Imaging;
using System.Windows.Navigation;
using System.Windows.Shapes;
using System.Windows.Media.Media3D;
using MindFusion.Charting.Wpf;

namespace Demo
{
	/// <summary>
	/// Interaction logic for BarTypes3D.xaml
	/// </summary>
	public partial class BarTypes3D : UserControl
	{
		SalesList sales;
		DoubleCollection data;

        BrushCollection brushes = Utilities.GetGradientFills();
        BrushCollection strokes = Utilities.GetGradientStrokes();

		public BarTypes3D()
		{
			InitializeComponent();
            System.Windows.Controls.Grid.SetZIndex(barChart3D1, -1);
			barChart3D1.BeginInit();

			barChart3D1.TitleVisibility = Visibility.Collapsed;
			barChart3D1.RotationAngle = 30;
			barChart3D1.RotationAxis = new Vector3D(-0.5, 0.88, 0.12);
			//barChart3D1.RotationAxis = new Vector3D(
			//    -0.491428430895548, 0.86773805432124, 0.0743556749033217);
			//barChart3D1.RotationAxis = new Vector3D(
			//	-0.434393277422911, 0.885159235368398, 0.166720150467227);
			barChart3D1.Scale = 170;
			//barChart3D1.YAxisSettings.TitleOffset = 4;
			//barChart3D1.XAxisSettings.TitleOffset = 3;
			//barChart3D1.XOffset = 3.5;


            barChart3D1.XAxisSettings.TitleOffset = 5;
           
            barChart3D1.XAxisSettings.TitleFontSize = 12;
            barChart3D1.XAxisSettings.LabelFontSize = 12;
            barChart3D1.XAxisSettings.LabelOffset = 3;
            barChart3D1.XAxisSettings.TitleStroke = Brushes.White;
            barChart3D1.XAxisSettings.LabelStroke = Brushes.White;

            barChart3D1.YAxisSettings.TitleOffset = 5;           
            barChart3D1.YAxisSettings.TitleFontSize = 12;
            barChart3D1.YAxisSettings.LabelFontSize = 12;
            barChart3D1.YAxisSettings.LabelOffset = 3;
            barChart3D1.YAxisSettings.TitleStroke = Brushes.White;
            barChart3D1.YAxisSettings.LabelStroke = Brushes.White;

			
			sales = new SalesList();
			barChart3D1.DataSource = sales;
            data = new DoubleCollection() { 1, 2, 3, 4, 5, 6 };
			AddSingleVertSeries(BarType3D.Vertical);
			SetVertAxesSettings();

            barChart3D1.XAxisSettings.LabelFormat = "0.##";
            barChart3D1.YAxisSettings.LabelFormat = "0.##";

            

			barChart3D1.EndInit();
		}

		private void cbHorizontal_Checked(object sender, RoutedEventArgs e)
		{
			SetHorSettings();
		}

		private void cbHorizontal_Unchecked(object sender, RoutedEventArgs e)
		{
			SetVertSettings();
		}

		private void cbLineType_SelectionChanged(object sender, SelectionChangedEventArgs e)
		{
			if (cbHorizontal == null)
				return;
			if (cbHorizontal.IsChecked == true)
				SetHorSettings();
			else
				SetVertSettings();

			//barChart3D1.CameraType = CameraType.Orthographic;
		}

		private void SetVertSettings()
		{
			barChart3D1.BeginInit();

			switch (cbBarType.SelectedIndex)
			{
				case 0:
					{
						AddSingleVertSeries(BarType3D.Vertical);
						SetVertAxesSettings();
						break;
					}
				case 1:
					{
						AddMultipleVertSeries(BarType3D.Vertical);
						SetVertAxesSettings();
						break;
					}
				case 2:
					{

						AddMultipleVertSeries(BarType3D.VerticalInColumn);
						SetVertAxesSettings();
						break;
					}
				case 3:
					{

						AddMultipleVertSeries(BarType3D.VerticalStack);
						SetVertAxesSettings();
						break;
					}		
			}

			barChart3D1.EndInit();
		}

		private void SetHorSettings()
		{
			barChart3D1.BeginInit();

			switch (cbBarType.SelectedIndex)
			{
				case 0:
					{

						AddSingleHorSeries(BarType3D.Horizontal);
						SetHorAxesSettings();
						break;
					}
				case 1:
					{
						AddMultipleHorSeries(BarType3D.Horizontal);
						SetHorAxesSettings();
						break;
					}

				case 2:
					{
						AddMultipleHorSeries(BarType3D.HorizontalInColumn);
						SetHorAxesSettings();
						break;
					}
				case 3:
					{
						AddMultipleHorSeries(BarType3D.HorizontalStack);
						SetHorAxesSettings();
						break;
					}
			}

			barChart3D1.EndInit();
		}

		private void AddSingleVertSeries(BarType3D barType)
		{
			barChart3D1.Series.Clear();
			barChart3D1.BarType3D = barType;
            BarSeries series1 = new BarSeries() { Fills = new BrushCollection(), Strokes = new BrushCollection() };
			//series1.BarType = barType;
			series1.XData = data;
			series1.Title = "Profit";
			series1.YDataPath = "Profit";
			series1.Fills.Add(brushes[brushes.Count - 1]);
			series1.Strokes.Add(strokes[brushes.Count - 1]);
			
			barChart3D1.Series.Add(series1);
		}

		private void AddSingleHorSeries(BarType3D barType)
		{
			barChart3D1.Series.Clear();
			barChart3D1.BarType3D = barType;
            BarSeries series1 = new BarSeries() { Fills = new BrushCollection(), Strokes = new BrushCollection() };
			//series1.BarType = barType;
			series1.YData = data;
			series1.Title = "Profit";
			series1.XDataPath = "Profit";
			series1.Fills.Add(brushes[brushes.Count - 1]);
			series1.Strokes.Add(strokes[brushes.Count - 1]);
			barChart3D1.Series.Add(series1);
		}

		private void AddMultipleVertSeries(BarType3D barType)
		{
			barChart3D1.Series.Clear();
			barChart3D1.BarType3D = barType;

            BarSeries series1 = new BarSeries() { Fills = new BrushCollection(), Strokes = new BrushCollection() };
			//series1.BarType = barType;
			series1.XData = data;
			series1.Title = "Turnover";
			series1.YDataPath = "Turnover";
			series1.Fills.Add(brushes[brushes.Count - 1]);
			series1.Strokes.Add(strokes[brushes.Count - 1]);

            BarSeries series2 = new BarSeries() { Fills = new BrushCollection(), Strokes = new BrushCollection() };
			series2.XData = data;
			//series2.BarType = barType;
			series2.Title = "Profit";
			series2.YDataPath = "Profit";
			series2.Fills.Add(brushes[brushes.Count - 2]);
			series2.Strokes.Add(strokes[brushes.Count - 2]);

            BarSeries series3 = new BarSeries() { Fills = new BrushCollection(), Strokes = new BrushCollection() };
			//series3.BarType = barType;
			series3.XData = data;
			series3.Title = "Margin";
			series3.YDataPath = "Margin";
			series3.Fills.Add(brushes[3]);
			series3.Strokes.Add(strokes[3]);

			barChart3D1.Series.Add(series1);
			barChart3D1.Series.Add(series2);
			barChart3D1.Series.Add(series3);
		}

		private void AddMultipleHorSeries(BarType3D barType)
		{
			barChart3D1.Series.Clear();
			barChart3D1.BarType3D = barType;
            BarSeries series1 = new BarSeries() { Fills = new BrushCollection(), Strokes = new BrushCollection() };
			//series1.BarType = barType;
			series1.YData = data;
			series1.Title = "Turnover";
			series1.XDataPath = "Turnover";
			series1.Fills.Add(brushes[brushes.Count - 1]);
			series1.Strokes.Add(strokes[brushes.Count - 1]);

            BarSeries series2 = new BarSeries() { Fills = new BrushCollection(), Strokes = new BrushCollection() };
			//series2.BarType = barType;
			series2.Title = "Profit";
			series2.XDataPath = "Profit";
			series2.YData = data;
			series2.Fills.Add(brushes[brushes.Count - 2]);
			series2.Strokes.Add(strokes[brushes.Count - 2]);

            BarSeries series3 = new BarSeries() { Fills = new BrushCollection(), Strokes = new BrushCollection() };
			//series3.BarType = barType;
			series3.Title = "Margin";
			series3.YData = data;
			series3.XDataPath = "Margin";
			series3.Fills.Add(brushes[3]);
			series3.Strokes.Add(strokes[3]);

			barChart3D1.Series.Add(series1);
			barChart3D1.Series.Add(series2);
			barChart3D1.Series.Add(series3);
		}

		private void SetHorAxesSettings()
		{
            barChart3D1.XAxisSettings.Interval = barChart3D1.BarType3D == BarType3D.HorizontalStack ||
               barChart3D1.BarType3D == BarType3D.VerticalStack ? 200 : 50;
			barChart3D1.XAxisSettings.Title = "Sales";
			barChart3D1.XAxisSettings.LabelType = LabelType.AutoScale;

			barChart3D1.YAxisSettings.LabelType = LabelType.CustomText;
			barChart3D1.YAxisSettings.Interval = 1.0;
			barChart3D1.YAxisSettings.Title = "Month";
			barChart3D1.YLabelPath = "Month";

			barChart3D1.ModelWidth = 90;
			barChart3D1.ModelHeight = 60;
			barChart3D1.ModelDepth = 15;

			barChart3D1.GridType = GridType.Vertical;


            if (barChart3D1.BarType3D == BarType3D.HorizontalStack ||
               barChart3D1.BarType3D == BarType3D.VerticalStack)
                barChart3D1.XAxisSettings.MaxValue = 1000;
            else
                barChart3D1.XAxisSettings.MaxValue = double.NaN;


            barChart3D1.YAxisSettings.MaxValue = double.NaN;
		}

		private void SetVertAxesSettings()
		{
            barChart3D1.YAxisSettings.Interval = barChart3D1.BarType3D == BarType3D.HorizontalStack ||
                barChart3D1.BarType3D == BarType3D.VerticalStack ? 200 : 50;
			barChart3D1.YAxisSettings.Title = "Sales";
			barChart3D1.YAxisSettings.LabelType = LabelType.AutoScale;

			barChart3D1.XAxisSettings.LabelType = LabelType.CustomText;
			barChart3D1.XAxisSettings.Interval = 1.0;
			barChart3D1.XAxisSettings.Title = "Month";
			barChart3D1.XLabelPath = "Month";

			barChart3D1.ModelWidth = 90;
			barChart3D1.ModelHeight = 60;
			barChart3D1.ModelDepth = 15;

			barChart3D1.GridType = GridType.Horizontal;

            if (barChart3D1.BarType3D == BarType3D.HorizontalStack ||
               barChart3D1.BarType3D == BarType3D.VerticalStack)
                barChart3D1.YAxisSettings.MaxValue = 1000;
            else
                barChart3D1.YAxisSettings.MaxValue = double.NaN;

            barChart3D1.XAxisSettings.MaxValue = double.NaN;
		}

		private void Slider_ValueChanged(object sender, RoutedPropertyChangedEventArgs<double> e)
		{
			if (barChart3D1 == null)
				return;

			barChart3D1.CornerRadius3D = cornerSlider.Value;
		}

		private void slWidth_ValueChanged(object sender, RoutedPropertyChangedEventArgs<double> e)
		{
			if (barChart3D1 == null)
				return;

			barChart3D1.ModelWidth = slWidth.Value;
		}

		private void slHeight_ValueChanged(object sender, RoutedPropertyChangedEventArgs<double> e)
		{
			if (barChart3D1 == null)
				return;

			barChart3D1.ModelHeight = slHeight.Value;
		}

		private void slDepth_ValueChanged(object sender, RoutedPropertyChangedEventArgs<double> e)
		{
			if (barChart3D1 == null)
				return;

			barChart3D1.ModelDepth = slDepth.Value;
		}

        private void Border_SizeChanged(object sender, SizeChangedEventArgs e)
        {
            Window1.OnBackPanelSizeChanged(sender);
        }

        private void ComboBox_DropDownOpened(object sender, EventArgs e)
        {
            ((sender as ComboBox).Items[0] as ComboBoxItem).Visibility = Visibility.Collapsed;
        }

        private void ComboBox_DropDownClosed(object sender, EventArgs e)
        {
            ((sender as ComboBox).Items[0] as ComboBoxItem).Visibility = Visibility.Visible;
        }
	}
}
