﻿using System;
using System.Collections.Generic;
using System.Linq;
using System.Text;
using System.Windows;
using System.Windows.Controls;
using System.Windows.Data;
using System.Windows.Documents;
using System.Windows.Input;
using System.Windows.Media;
using System.Windows.Media.Imaging;
using System.Windows.Navigation;
using System.Windows.Shapes;
using MindFusion.Charting.Wpf;
using System.Windows.Media.Effects;

namespace Demo
{
	/// <summary>
	/// Interaction logic for DataBinding.xaml
	/// </summary>
	public partial class DataBinding : UserControl
	{
		public DataBinding()
		{
			InitializeComponent();

			PieSeries series = new PieSeries();
            series.Effect = new DropShadowEffect() { Opacity = 0.3, ShadowDepth = 3, };
			series.InnerLabelType = LabelType.CustomText;
			series.OuterLabelType = LabelType.Percents;
			series.DataPath = "Value";
			series.InnerLabelPath = "Label";
			series.OuterLabelPath = "Value";

            series.LabelForeground = Brushes.White;
            series.LabelFontFamily = new FontFamily("Arial");
            series.OuterLabelOffset = 40;

			pieChart1.Title = "";
            pieChart1.TitleFontFamily = new FontFamily("Arial");
            pieChart1.HorizontalContentAlignment = HorizontalAlignment.Center;
            pieChart1.VerticalContentAlignment = VerticalAlignment.Center;
            pieChart1.PlotAreaMargin = new Thickness(90, 20, 90, 20);

			pieChart1.Series.Clear();
			pieChart1.Series.Add(series);
			pieChart1.DataSource = new CustomData[] {
				new CustomData(2,"Bananas"),
				new CustomData(3,"Oranges"),
				new CustomData(6,"Apples"),
				new CustomData(4,"Pears"),
				new CustomData(7,"Kiwi"),
				new CustomData(9,"Strawberries"),
				new CustomData(5,"Papaya"),
				new CustomData(8,"Tangarines"),
			};

            BrushCollection col = Utilities.GetGradientFills();
            for (int i = 0; i < 8; i++)
            {
                LinearGradientBrush b = col[i] as LinearGradientBrush;
                Color light = b.GradientStops[0].Color;
                Color dark = b.GradientStops[1].Color;
                VisualBrush brush = Utilities.CreateVisualBrush(
                    dark, light, new SolidColorBrush(dark), 0, Orientation.Horizontal, 0);
                series.Fills.Add(brush);
                series.Strokes.Add(new SolidColorBrush(dark));
            }

			//series.Fills = Utilities.GetGradientFills();
			//series.Strokes = Utilities.GetGradientStrokes();
            series.StrokeThickness = 4;
			pieChart1.UpdateChart();
		}

		private void OnSliceIndexChecked(object sender, RoutedEventArgs e)
		{
			SetDetachedSlicesList();
		}

		private void OnSliceIndexUnchecked(object sender, RoutedEventArgs e)
		{
			SetDetachedSlicesList();
		}

		private void OnDoughnutChecked(object sender, RoutedEventArgs e)
		{
			if (pieChart1 != null)
			{
				PieSeries series = pieChart1.Series[0] as PieSeries;
				series.PieType = PieType.Doughnut2D;
				pieChart1.UpdateChart();
			}
		}

		private void OnDoughnutUnchecked(object sender, RoutedEventArgs e)
		{
			if (pieChart1 != null)
			{
				PieSeries series = pieChart1.Series[0] as PieSeries;
				series.PieType = PieType.Pie2D;
				pieChart1.UpdateChart();
			}
		}

		private void SetDetachedSlicesList()
		{
			//double[] d = new double[] { 0, 0, 0, 0, 0, 0, 0, 0 };
			//if (sliceIndex1.IsChecked == true)
			//    d[0] = slider.Value;
			//if (sliceIndex2.IsChecked == true)
			//    d[1] = slider.Value;
			//if (sliceIndex3.IsChecked == true)
			//    d[2] = slider.Value;
			//if (sliceIndex4.IsChecked == true)
			//    d[3] = slider.Value;
			//if (sliceIndex5.IsChecked == true)
			//    d[4] = slider.Value;
			//if (sliceIndex6.IsChecked == true)
			//    d[5] = slider.Value;
			//if (sliceIndex7.IsChecked == true)
			//    d[6] = slider.Value;
			//if (sliceIndex8.IsChecked == true)
			//    d[7] = slider.Value;

			//PieSeries series = pieChart1.Series[0] as PieSeries;
			//series.DetachedPiecesList = d;
		}

		private void Slider_ValueChanged(object sender, RoutedPropertyChangedEventArgs<double> e)
		{
			if (pieChart1 != null)
				SetDetachedSlicesList();
		}

        private void Border_SizeChanged(object sender, SizeChangedEventArgs e)
        {
            Window1.OnBackPanelSizeChanged(sender);
        }
	}

	public class CustomData
	{
		public CustomData()
		{

		}

		public CustomData(double d, string label)
		{
			value = d;
			this.Label = label;			
		}

		public double Value
		{
			get { return value; }
			set { this.value = value; }
		}

		public string Label
		{
			get { return label; }
			set { label = value; }
		}	

		private double value;	
		private string label;		
	}
}
