﻿using System;
using System.Collections.Generic;
using System.Linq;
using System.Text;
using System.Windows;
using System.Windows.Controls;
using System.Windows.Data;
using System.Windows.Documents;
using System.Windows.Input;
using System.Windows.Media;
using System.Windows.Media.Imaging;
using System.Windows.Navigation;
using System.Windows.Shapes;
using MindFusion.Charting.Wpf;
using System.Windows.Media.Effects;

namespace Demo
{
    /// <summary>
    /// Interaction logic for Effects.xaml
    /// </summary>
    public partial class Effects : UserControl
    {
        BrushCollection brushes = Utilities.GetGradientFills();
        BrushCollection strokes = Utilities.GetGradientStrokes();

        public Effects()
        {
            InitializeComponent();

            //BarChart
            BarSeries barSerie = new BarSeries();
            barChart.Series.Add(barSerie);
            barSerie.XData = new DoubleCollection() { 1, 2, 3, 4 };
            barSerie.YData = new DoubleCollection() { 28, 42, 17, 82 };
            barSerie.InnerLabelType = LabelType.Empty;

           

            for (int i = 0; i < 6; i++)
            {
                LinearGradientBrush b = brushes[i] as LinearGradientBrush;
                Color light = b.GradientStops[0].Color;
                Color dark = b.GradientStops[1].Color;
                VisualBrush brush = Utilities.CreateVisualBrush(
                    dark, light, new SolidColorBrush(dark), 4, Orientation.Vertical, 10);
                barSerie.Fills.Add(brush);
            }
            //barSerie.Fills = brushes;
            barSerie.Strokes = strokes;
            barSerie.Effect = new DropShadowEffect() { Opacity = 0.3, ShadowDepth = 3, };
            barSerie.StrokeThickness = 0;
            barSerie.ToolTipType = ToolTipType.ChartData;
            barChart.XAxes[0].Title = "";
            barChart.XAxes[0].LabelType = LabelType.Empty;
            barChart.YAxes[0].Title = "";
            barChart.YAxes[0].LabelStroke = Brushes.White;
            barChart.YAxes[0].VertLabelAlignment = VerticalAlignment.Center;


            //LineChart
            LineSeries lineSerie = new LineSeries();
            lineChart.Series.Add(lineSerie);
            lineSerie.Labels = new string[] { };
            lineSerie.Effect = new DropShadowEffect() { Opacity = 0.3, ShadowDepth = 3, };

            for (int i = 0; i < 6; i++)
            {
                LinearGradientBrush b = brushes[i] as LinearGradientBrush;
                Color light = b.GradientStops[0].Color;
                Color dark = b.GradientStops[1].Color;
                VisualBrush brush = Utilities.CreateVisualBrush(
                    dark, light, new SolidColorBrush(dark), 0, Orientation.Horizontal, 0);
                lineSerie.Fills.Add(brush);
                lineSerie.Strokes.Add(new SolidColorBrush(dark));

                lineSerie.ScatterFills.Add(brush);
                lineSerie.ScatterStrokes.Add(new SolidColorBrush(dark));
            }
            //lineSerie.Fills = brushes;
            //lineSerie.Strokes = strokes;
            //lineSerie.ScatterFills = strokes;
            //lineSerie.ScatterStrokes = brushes;
            lineSerie.ScatterType = ScatterType.Square;
            lineSerie.ScatterSize = 15;
            lineSerie.StrokeThickness = 4;
            lineChart.LineType = LineType.Area2D;
            lineSerie.XData = new DoubleCollection() { 0, 1, 2, 3 };
            lineSerie.YData = new DoubleCollection() { 28, 42, 17, 82 };

            lineChart.XAxes[0].Title = "";
            lineChart.XAxes[0].LabelType = LabelType.Empty;
            lineChart.YAxes[0].Title = "";
            lineChart.YAxes[0].LabelStroke = Brushes.White;
            lineChart.YAxes[0].VertLabelAlignment = VerticalAlignment.Center;



            //PieChart
            PieSeries pieSerie = new PieSeries();
            pieChart.Series.Add(pieSerie);
            pieSerie.Data = new DoubleCollection() { 28, 42, 37, 82 };
            pieSerie.Effect = new DropShadowEffect() { Opacity = 0.3, ShadowDepth = 3, };

            for (int i = 0; i < 6; i++)
            {
                LinearGradientBrush b = brushes[i] as LinearGradientBrush;
                Color light = b.GradientStops[0].Color;
                Color dark = b.GradientStops[1].Color;
                VisualBrush brush = Utilities.CreateVisualBrush(
                    dark, light, new SolidColorBrush(dark), 0, Orientation.Horizontal, 0);
                pieSerie.Fills.Add(brush);
                pieSerie.Strokes.Add(new SolidColorBrush(dark));

                //pieSerie.ScatterFills.Add(brush);
                //pieSerie.ScatterStrokes.Add(new SolidColorBrush(dark));
            }

           // pieSerie.Fills = brushes;
            //pieSerie.Strokes = strokes;
            pieSerie.OuterLabelType = LabelType.Empty;
            pieSerie.InnerLabelType = LabelType.Percents;
            pieSerie.StrokeThickness = 4;

            //RadarChar
            RadarSeries radarSerie = new RadarSeries();
            radarChart.Series.Add(radarSerie);
            radarSerie.Data = new DoubleCollection() { 28, 42, 37, 82, 60 };
            radarSerie.Effect = new DropShadowEffect() { Opacity = 0.3, ShadowDepth = 3, };

            for (int i = 0; i < 6; i++)
            {
                LinearGradientBrush b = brushes[i] as LinearGradientBrush;
                Color light = b.GradientStops[0].Color;
                Color dark = b.GradientStops[1].Color;
                VisualBrush brush = Utilities.CreateVisualBrush(
                    dark, light, new SolidColorBrush(dark), 0, Orientation.Horizontal, 0);
                radarSerie.Fills.Add(brush);
                radarSerie.Strokes.Add(new SolidColorBrush(dark));

                radarSerie.RadarScatterFills.Add(brush);
                radarSerie.RadarScatterStrokes.Add(new SolidColorBrush(dark));
            }

            //radarSerie.Fills = brushes;
            //radarSerie.Strokes = strokes;
            //radarSerie.RadarScatterFills = strokes;
            //radarSerie.RadarScatterStrokes = brushes;
            radarSerie.LabelBackground = brushes[0];
            radarSerie.LabelBorderBrush = strokes[0];
            radarSerie.LabelForeground = Brushes.White;
            radarSerie.StrokeThickness = 4;
            radarSerie.ScatterSize = 15;
            radarChart.TitleVisibility = Visibility.Collapsed;
            radarChart.InnerLabelAngle = 90;
            radarChart.OuterStrokeDashArray = null;
            radarChart.InnerStrokeDashArray = null;
            radarChart.OuterLabelBackground = null;
            radarChart.OuterLabelType = LabelType.Empty;
            radarChart.OuterLabelBorderThickness = new Thickness(0);
            radarChart.InnerLabelBackground = Brushes.White;
            radarChart.InnerLabelBorderThickness = new Thickness(1);
            radarChart.InnerLabelBorderBrush = Brushes.Black;

            VisualBrush fb1 = Utilities.CreateVisualBrush(
                Colors.Gray, Colors.White, new SolidColorBrush(Colors.Gray), 0, Orientation.Horizontal, 0);
            fb1.Opacity = 0.2;

            lineChart.GridFills.Add(fb1);
            barChart.GridFills.Add(fb1);

            radarChart.SectionBrushes.Add(fb1);
            radarChart.SectionBrushes.Add(Brushes.Transparent);
            radarChart.SectionBrushes.Add(Brushes.Transparent);
            radarChart.SectionBrushes.Add(Brushes.Transparent);
            radarChart.SectionBrushes.Add(Brushes.Transparent);
            radarChart.SectionBrushes.Add(Brushes.Transparent);

        }

        private void cbEffect_SelectionChanged(object sender, SelectionChangedEventArgs e)
        {
            if (barChart == null)
                return;
            ComboBox box = sender as ComboBox;
            if (box.SelectedIndex == 0)
            {
                barChart.Series[0].Effect = new DropShadowEffect() { Opacity = 0.5, ShadowDepth = shadowSlider.Value };
                lineChart.Series[0].Effect = new DropShadowEffect() { Opacity = 0.5, ShadowDepth = shadowSlider.Value };
                pieChart.Series[0].Effect = new DropShadowEffect() { Opacity = 0.5, ShadowDepth = shadowSlider.Value };
                radarChart.Series[0].Effect = new DropShadowEffect() { Opacity = 0.5, ShadowDepth = shadowSlider.Value };

                blurSlider.Visibility = Visibility.Collapsed;
                blurText.Visibility = Visibility.Collapsed;
                shadowSlider.Visibility = Visibility.Visible;
                shadowText.Visibility = Visibility.Visible;
            }
            if (box.SelectedIndex == 1)
            {
                barChart.Series[0].Effect = new BlurEffect() { Radius = blurSlider.Value };
                lineChart.Series[0].Effect = new BlurEffect() { Radius = blurSlider.Value };
                pieChart.Series[0].Effect = new BlurEffect() { Radius = blurSlider.Value };
                radarChart.Series[0].Effect = new BlurEffect() { Radius = blurSlider.Value };

                blurSlider.Visibility = Visibility.Visible;
                blurText.Visibility = Visibility.Visible;
                shadowSlider.Visibility = Visibility.Collapsed;
                shadowText.Visibility = Visibility.Collapsed;
            }
            if (box.SelectedIndex == 2)
            {
                barChart.Series[0].Effect = null;
                lineChart.Series[0].Effect = null;
                pieChart.Series[0].Effect = null;
                radarChart.Series[0].Effect = null;

                blurSlider.Visibility = Visibility.Collapsed;
                blurText.Visibility = Visibility.Collapsed;
                shadowSlider.Visibility = Visibility.Collapsed;
                shadowText.Visibility = Visibility.Collapsed;
            }


            barChart.UpdateChart();
            lineChart.UpdateChart();
            pieChart.UpdateChart();
            radarChart.UpdateChart();
        }

        private void shadowSlider_ValueChanged(object sender, RoutedPropertyChangedEventArgs<double> e)
        {
            if (barChart == null || cbEffect.SelectedIndex != 0)
                return;
            ComboBox box = sender as ComboBox;

            (barChart.Series[0].Effect as DropShadowEffect).ShadowDepth = e.NewValue;
            (lineChart.Series[0].Effect as DropShadowEffect).ShadowDepth = e.NewValue;
            (pieChart.Series[0].Effect as DropShadowEffect).ShadowDepth = e.NewValue;
            (radarChart.Series[0].Effect as DropShadowEffect).ShadowDepth = e.NewValue;


            barChart.UpdateChart();
            lineChart.UpdateChart();
            pieChart.UpdateChart();
        }

        private void blurSlider_ValueChanged(object sender, RoutedPropertyChangedEventArgs<double> e)
        {
            if (barChart == null || cbEffect.SelectedIndex != 1)
                return;
            ComboBox box = sender as ComboBox;

            (barChart.Series[0].Effect as BlurEffect).Radius = e.NewValue;
            (lineChart.Series[0].Effect as BlurEffect).Radius = e.NewValue;
            (pieChart.Series[0].Effect as BlurEffect).Radius = e.NewValue;
            (radarChart.Series[0].Effect as BlurEffect).Radius = e.NewValue;


            barChart.UpdateChart();
            lineChart.UpdateChart();
            pieChart.UpdateChart();
        }

        internal void Border_SizeChanged(object sender, SizeChangedEventArgs e)
        {
            Window1.OnBackPanelSizeChanged(sender);
        }

        private void Grid_SizeChanged(object sender, SizeChangedEventArgs e)
        {
            double width = e.NewSize.Width;
            double heigth = e.NewSize.Height;
            for (int i = 0; i < 2; i++)
            {
                chartGrid.RowDefinitions[0].Height = new GridLength(Math.Round(heigth / 2));
            }
        }
    }
}
