﻿using System;
using System.Collections.Generic;
using System.Linq;
using System.Text;
using System.Windows;
using System.Windows.Controls;
using System.Windows.Data;
using System.Windows.Documents;
using System.Windows.Input;
using System.Windows.Media;
using System.Windows.Media.Imaging;
using System.Windows.Navigation;
using System.Windows.Shapes;
using MindFusion.Charting.Wpf;
using System.Windows.Media.Effects;

namespace Demo
{
    /// <summary>
    /// Interaction logic for HitTest.xaml
    /// </summary>
    public partial class HitTest : UserControl
    {
        public HitTest()
        {
            BrushCollection brushes = Utilities.GetGradientFills();
            BrushCollection strokes = Utilities.GetGradientStrokes();

            InitializeComponent();

            //BarChart
            BarSeries barSerie = new BarSeries();
            barChart.Series.Add(barSerie);
            barSerie.XData = new DoubleCollection() { 1, 2, 3, 4 };
            barSerie.YData = new DoubleCollection() { 28, 42, 17, 82 };
            barSerie.InnerLabelType = LabelType.Empty;
            barSerie.Fills = new BrushCollection();
            barSerie.Strokes = new BrushCollection();

            LinearGradientBrush b = brushes[7] as LinearGradientBrush;
            Color light = b.GradientStops[0].Color;
            Color dark = b.GradientStops[1].Color;
            VisualBrush brush = Utilities.CreateVisualBrush(
                dark, light, new SolidColorBrush(dark), 4, Orientation.Vertical, 4);

            barSerie.Fills.Add(brush);
            barSerie.Strokes.Add(new SolidColorBrush(dark));
            barSerie.StrokeThickness = 0;
            barSerie.YData = new DoubleCollection() { 51, 72, 64, 87 };
            barChart.BarType = BarType.VerticalOverlay;

            BarSeries serie = new BarSeries()
            {
                Fills = new BrushCollection(),
                Strokes = new BrushCollection(),               
            };
            serie.Effect = new DropShadowEffect() { Opacity = 0.3, ShadowDepth = 3, };

            b = brushes[6] as LinearGradientBrush;
            light = b.GradientStops[0].Color;
            dark = b.GradientStops[1].Color;
            brush = Utilities.CreateVisualBrush(
                dark, light, new SolidColorBrush(dark), 4, Orientation.Vertical, 4);

            serie.Fills.Add(brush);
            serie.Strokes.Add(new SolidColorBrush(dark));
            serie.StrokeThickness = 0;
            serie.XData = new DoubleCollection() { 1, 2, 3, 4 };
            serie.YData = new DoubleCollection() { 37, 59, 44, 70 };
            barChart.BarType = BarType.VerticalOverlay;
            barChart.Series.Add(serie);

            barChart.XAxes[0].Title = "";
            barChart.XAxes[0].LabelType = LabelType.Empty;
            barChart.YAxes[0].Title = "";
            barChart.YAxes[0].VertLabelAlignment = VerticalAlignment.Center;
            barChart.YAxes[0].LabelStroke = Brushes.White;



            //LineChart
            LineSeries lineSerie = new LineSeries();
            lineChart.Series.Add(lineSerie);
            lineSerie.Labels = new string[] { };
            lineSerie.Effect = new DropShadowEffect() { Opacity = 0.3, ShadowDepth = 3, };
            lineChart.LineType = LineType.Area2D;
            lineSerie.Fills = new BrushCollection();
            lineSerie.Strokes = new BrushCollection();
            lineSerie.ScatterStrokes = new BrushCollection();
            lineSerie.ScatterFills = new BrushCollection();
            lineSerie.Fills.Add(Window1.TransformBrush(brushes[0],255));
            lineSerie.Strokes.Add(new SolidColorBrush((brushes[0] as LinearGradientBrush).GradientStops[1].Color));
            lineSerie.StrokeThickness = 4;
            for (int i = 0; i < 8; i++)
            {
                b = brushes[i] as LinearGradientBrush;
                light = b.GradientStops[0].Color;
                dark = b.GradientStops[1].Color;
                brush = Utilities.CreateVisualBrush(
                    dark, light, new SolidColorBrush(dark), 0, Orientation.Horizontal, 0);
                lineSerie.ScatterFills.Add(brush);
            }
            lineSerie.ScatterStrokes = strokes;
            lineSerie.ScatterType = ScatterType.Square;
            lineSerie.ScatterSize = 15;
            lineChart.LineType = LineType.Area2D;
            lineSerie.XData = new DoubleCollection() { 0, 1, 2, 3};
            lineSerie.YData = new DoubleCollection() { 28, 82, 60, 25 };

           

            lineChart.XAxes[0].Title = "";
            lineChart.XAxes[0].LabelType = LabelType.Empty;
            lineChart.YAxes[0].Title = "";
            lineChart.YAxes[0].VertLabelAlignment = VerticalAlignment.Center;
            lineChart.YAxes[0].LabelStroke = Brushes.White;

            //PieChart
            PieSeries pieSerie = new PieSeries();
            pieChart.Series.Add(pieSerie);
            pieSerie.Data = new DoubleCollection() { 28, 42, 17, 62 };
            pieSerie.Effect = new DropShadowEffect() { Opacity = 0.3, ShadowDepth = 3, };
            pieSerie.Fills = new BrushCollection();
            pieSerie.Strokes = new BrushCollection();

           
            for (int i = 0; i < 8; i++)
            {
                b = brushes[i] as LinearGradientBrush;
                light = b.GradientStops[0].Color;
                dark = b.GradientStops[1].Color;
                brush = Utilities.CreateVisualBrush(
                    dark, light, new SolidColorBrush(dark), 0, Orientation.Horizontal, 0);
                pieSerie.Fills.Add(brush);
                pieSerie.Strokes.Add(new SolidColorBrush(dark));
            }
            //pieSerie.Fills = brushes;
            //pieSerie.Strokes = strokes;
            pieSerie.StrokeThickness = 4;
            pieSerie.OuterLabelType = LabelType.Empty;
            pieSerie.InnerLabelType = LabelType.Percents;

            pieChart.PlotAreaMargin = new Thickness(30,0,30,10);
            this.MouseDown += new MouseButtonEventHandler(MainWindow_MouseDown);



           
            VisualBrush fb1 = Utilities.CreateVisualBrush(
                Colors.Gray, Colors.White, new SolidColorBrush(Colors.Gray), 0, Orientation.Horizontal, 0);
            fb1.Opacity = 0.2;
          
            lineChart.GridFills.Add(fb1);           
            barChart.GridFills.Add(fb1);
           
        }

        void MainWindow_MouseDown(object sender, MouseButtonEventArgs e)
        {
            List<ChartElement> barList = barChart.HitTest(e.GetPosition(barChart));
            List<ChartElement> pieList = pieChart.HitTest(e.GetPosition(pieChart));
            List<ChartElement> lineList = lineChart.HitTest(e.GetPosition(lineChart));


            for (int i = 0; i < barList.Count; i++)
            {
                Bar bar = barList[i] as Bar;
                MessageBox.Show(bar.GetType().ToString() + " {Value: " + bar.Value.ToString() + "}");
            }
            for (int i = 0; i < pieList.Count; i++)
            {
                PieSlice pie = pieList[i] as PieSlice;
                MessageBox.Show(pie.GetType().ToString() + " {Value: " + pie.SliceValue.ToString() + "}");
            }
            for (int i = 0; i < lineList.Count; i++)
            {
                if (lineList[i] is Scatter)
                {
                    Scatter scatter = lineList[i] as Scatter;
                    MessageBox.Show(scatter.GetType().ToString() + " {Index: " + scatter.ScatterIndex.ToString() + "}");
                }
                else
                {
                    MindFusion.Charting.Wpf.Line line = lineList[i] as MindFusion.Charting.Wpf.Line;
                    MessageBox.Show(line.GetType().ToString() + " {Values: " + line.Points[0].Y.ToString() + ", " 
                       + line.Points[1].Y.ToString() + ", " + line.Points[2].Y.ToString()  + ", " + line.Points[3].Y.ToString() + "}");
                }
              
            }
        }

        private void Border_SizeChanged(object sender, SizeChangedEventArgs e)
        {
            Window1.OnBackPanelSizeChanged(sender);
        }
    }
}
