﻿using System;
using System.Collections.Generic;
using System.Linq;
using System.Text;
using System.Windows;
using System.Windows.Controls;
using System.Windows.Data;
using System.Windows.Documents;
using System.Windows.Input;
using System.Windows.Media;
using System.Windows.Media.Imaging;
using System.Windows.Navigation;
using System.Windows.Shapes;
using MindFusion.Charting.Wpf;
using System.Windows.Media.Effects;

namespace Demo
{
	/// <summary>
	/// Interaction logic for Legend.xaml
	/// </summary>
	public partial class Legend : UserControl
	{
		private DropShadowEffect effect = new DropShadowEffect() { Opacity = 0.3, ShadowDepth = 3};

        BrushCollection brushList = Utilities.GetGradientFills();

		public Legend()
		{
			InitializeComponent();

			effect = new DropShadowEffect()
			{
				Opacity = 0.7,
				ShadowDepth = 3,
			};

		
			pieChart.Title = "Sales in Our Major Stores";

            DoubleCollection list = new DoubleCollection(){
				100.00, 60.00, 90.50, 73.33, 12.80, 24.56, 13.09, 56.19, 
			};

            PieSeries series = new PieSeries();
            for (int i = 0; i < brushList.Count; i++)
                series.Strokes.Add(new SolidColorBrush((brushList[i] as LinearGradientBrush).GradientStops[1].Color));

            for (int i = 0; i < brushList.Count; i++)
                brushList[i] = Window1.TransformBrush(brushList[i], 255);

            series.LabelForeground = Brushes.White;
            series.Effect = effect;
            series.Fills = brushList;
            
			//series.Strokes = Utilities.GetGradientStrokes();
			series.Data = list;
			series.PieType = PieType.Doughnut2D;
			series.OuterLabelType = LabelType.ChartData;
            series.DetachedSlicesList = new DoubleCollection() { 0, 0, 0, 0, 0, 0, 0, 50 };
			series.OuterLabelOffset = 25;
            series.StartAngle = 0;
            series.StrokeThickness = 4;
			pieChart.Legends.Add(GetSeriesLegend());		
			pieChart.Series.Clear();
			pieChart.Series.Add(series);
           
			verticalAlignment.SelectedIndex = 0;
			horizontalAlignment.SelectedIndex = 0;
			//border.SelectedIndex = 2;
			dockAlignment.SelectedIndex = 0;

            pieChart.TitleMargin = new Thickness(0, 0, 0, 20);
            pieChart.Foreground = Brushes.White;
		}


        private SeriesLegend GetSeriesLegend()
		{
			SeriesLegend seriesLegend = new SeriesLegend();
            seriesLegend.BrushesSource = brushList;          
			seriesLegend.BorderBrush = Brushes.Silver;
            seriesLegend.BorderThickness = new Thickness(0);
			seriesLegend.Background = new SolidColorBrush(Color.FromRgb(240, 240, 240));
            seriesLegend.Foreground = Brushes.White;
            seriesLegend.Padding = new Thickness(10);
            seriesLegend.Margin = new Thickness(0,0,0,0);
			seriesLegend.LabelsSource = new List<string>() {
				"Vienna", "Sofia", "Buenos Aires", "Berlin",
				"Beijing","Ottawa","San Francisco","Cairo",
			};
			//seriesLegend.Effect = effect;
			seriesLegend.SnapsToDevicePixels = true;

            seriesLegend.SizeChanged += new SizeChangedEventHandler(seriesLegend_SizeChanged);
			return seriesLegend;
		}

        void seriesLegend_SizeChanged(object sender, SizeChangedEventArgs e)
        {
            Window1.OnBackPanelSizeChanged(sender);
        }

		private void verticalAlignment_SelectionChanged(object sender, SelectionChangedEventArgs e)
		{
			if (pieChart != null)
			{
				SeriesLegend legend = pieChart.Legends[0] as SeriesLegend;
				if (verticalAlignment.SelectedIndex == 0)
					legend.VerticalAlignment = VerticalAlignment.Top;
				else if (verticalAlignment.SelectedIndex == 1)
					legend.VerticalAlignment = VerticalAlignment.Center;
				else if (verticalAlignment.SelectedIndex == 2)
					legend.VerticalAlignment = VerticalAlignment.Bottom;
				else if (verticalAlignment.SelectedIndex == 3)
					legend.VerticalAlignment = VerticalAlignment.Stretch;              
			}

            SetDock();
		}

		private void horizontalAlignment_SelectionChanged(object sender, SelectionChangedEventArgs e)
		{
			if (pieChart != null)
			{
				SeriesLegend legend = pieChart.Legends[0] as SeriesLegend;
				if (horizontalAlignment.SelectedIndex == 0)
					legend.HorizontalAlignment = HorizontalAlignment.Left;
				else if (horizontalAlignment.SelectedIndex == 1)
					legend.HorizontalAlignment = HorizontalAlignment.Center;
				else if (horizontalAlignment.SelectedIndex == 2)
					legend.HorizontalAlignment = HorizontalAlignment.Right;
				else if (horizontalAlignment.SelectedIndex == 3)
					legend.HorizontalAlignment = HorizontalAlignment.Stretch;
               
			}

            SetDock();
		}

		private void border_SelectionChanged(object sender, SelectionChangedEventArgs e)
		{
			if (pieChart != null)
			{
				SeriesLegend legend = pieChart.Legends[0] as SeriesLegend;
                //if (border.SelectedIndex == 0)
                //{
                //    legend.BorderThickness = new Thickness(0);
                //    legend.CornerRadius = new CornerRadius(0);
                //}
                //else if (border.SelectedIndex == 1)
                //{
                //    legend.BorderThickness = new Thickness(0);
                //    legend.CornerRadius = new CornerRadius(0);
                //}
                //else if (border.SelectedIndex == 2)
                //{
                //    legend.BorderThickness = new Thickness(0);
                //    legend.CornerRadius = new CornerRadius(5);
                //}			
			}
		}

		private void dockAlignment_SelectionChanged(object sender, SelectionChangedEventArgs e)
		{
            SetDock();
		}

        private void SetDock()
        {
            SeriesLegend legend = pieChart.Legends[0] as SeriesLegend;
            LayoutPanel.SetDock(legend, Dock.Bottom);
            if (dockAlignment.SelectedIndex == 0)
            {
                LayoutPanel.SetDock(legend, Dock.Right);
                LayoutPanel.SetDock(legend, Dock.Left);
                horizontalAlignment.IsEnabled = false;
                verticalAlignment.IsEnabled = true;
            }
            if (dockAlignment.SelectedIndex == 1)
            {
                LayoutPanel.SetDock(legend, Dock.Bottom);
                LayoutPanel.SetDock(legend, Dock.Top);
                horizontalAlignment.IsEnabled = true;
                verticalAlignment.IsEnabled = false;
            }
            if (dockAlignment.SelectedIndex == 2)
            {
                LayoutPanel.SetDock(legend, Dock.Left);
                LayoutPanel.SetDock(legend, Dock.Right);
                horizontalAlignment.IsEnabled = false;
                verticalAlignment.IsEnabled = true;
            }
            if (dockAlignment.SelectedIndex == 3)
            {
                LayoutPanel.SetDock(legend, Dock.Top);
                LayoutPanel.SetDock(legend, Dock.Bottom);
                horizontalAlignment.IsEnabled = true;
                verticalAlignment.IsEnabled = false;
            }
        }

        private void Border_SizeChanged(object sender, SizeChangedEventArgs e)
        {
            Window1.OnBackPanelSizeChanged(sender);
        }

        private void ComboBox_DropDownOpened(object sender, EventArgs e)
        {
            ((sender as ComboBox).Items[0] as ComboBoxItem).Visibility = Visibility.Collapsed;
        }

        private void ComboBox_DropDownClosed(object sender, EventArgs e)
        {
            ((sender as ComboBox).Items[0] as ComboBoxItem).Visibility = Visibility.Visible;
        }
	}
}
