﻿using System;
using System.Collections.Generic;
using System.Linq;
using System.Text;
using System.Windows;
using System.Windows.Controls;
using System.Windows.Data;
using System.Windows.Documents;
using System.Windows.Input;
using System.Windows.Media;
using System.Windows.Media.Imaging;
using System.Windows.Navigation;
using System.Windows.Shapes;
using MindFusion.Charting.Wpf;
using System.Windows.Media.Effects;

namespace Demo
{
	/// <summary>
	/// Interaction logic for LineBarCharts.xaml
	/// </summary>
	public partial class LineBarCharts : UserControl
	{
		private DoubleCollection xData;
		private DoubleCollection yData;
		private DoubleCollection xbarData;
		private List<string> xLabelData;
		private List<double> barInnerLabelData;
		private DoubleCollection ybarData;

		public LineBarCharts()
		{
			InitializeComponent();

            LinearGradientBrush d = Utilities.GetGradientFills()[3] as LinearGradientBrush;
            Color dc = d.GradientStops[1].Color;
            SolidColorBrush stroke = new SolidColorBrush(dc);


            lineChart.BeginInit();
            barChart.BeginInit();

			//line
			xData = new DoubleCollection() {
				0, 6, 12, 18, 24, 30, 36, 42, 48, 54, 60
			};
			yData = new DoubleCollection() {
				20, 73, 31, 49, 15, 87, 25, 76, 48, 71, 59
			};


			//bar
			xbarData = new DoubleCollection() {
				6, 12, 18, 24, 30, 36, 42, 48, 54, 60
			};
			xLabelData = new List<string>() {
			    "Jan", "Feb", "Mar", "Apr", "May", "Jun",
				"Jul", "Aug", "Sep", "Oct", "Nov", "Dec",
			};
			barInnerLabelData = new List<double>(new double[] {
			    6, 12, 18, 24, 30, 36, 42, 48, 54, 60
			});
			ybarData = new DoubleCollection() {
				20, 73, 31, 49, 15, 87, 25, 76, 48, 71
			};


			//lineChart
			lineChart.TitleVisibility = Visibility.Collapsed;
			lineChart.Series.Clear();
            lineChart.LineType = LineType.Area2D;
            LineSeries lineSeries = new LineSeries()
            {
                Fills = new BrushCollection(),
                Strokes = new BrushCollection(),
                ScatterFills = new BrushCollection(),
                ScatterStrokes = new BrushCollection(),
            };
            lineSeries.Effect = new DropShadowEffect() { Opacity = 0.5, ShadowDepth = 3, };
			lineSeries.Fills.Add(Window1.TransformBrush(Utilities.GetGradientFills()[3],255));
            lineSeries.Strokes.Add(stroke);
            lineSeries.ScatterFills.Add(Window1.TransformBrush(Utilities.GetGradientFills()[3], 255));
			lineSeries.ScatterStrokes.Add(stroke);
			lineSeries.ScatterType = ScatterType.Circle;
			lineSeries.ScatterSize = 20;
			lineSeries.XData = xData;
			lineSeries.YData = yData;
			lineSeries.Labels = yData;
            lineSeries.StrokeThickness = 4;
            lineSeries.LabelForeground = Brushes.White;

			lineChart.Series.Add(lineSeries);

			//lineChart.YAxisSettings
			lineChart.YAxes[0].Interval = 20;
            lineChart.YAxes[0].LabelType = LabelType.AutoScale;
            lineChart.YAxes[0].MinValue = 0;
            lineChart.YAxes[0].MaxValue = 100;
            lineChart.YAxes[0].Title = "";
            lineChart.YAxes[0].LabelOffset = 10;
            lineChart.YAxes[0].VertLabelAlignment = VerticalAlignment.Center;
            lineChart.YAxes[0].LabelStroke = Brushes.White;

			//lineChart.XAxisSettings
            lineChart.XAxes[0].Interval = 6;
            lineChart.XAxes[0].LabelType = LabelType.CustomText;
            lineChart.XAxes[0].MinValue = 0;
            lineChart.XAxes[0].MaxValue = 60;
            lineChart.XAxes[0].Title = "";
            lineChart.XAxes[0].LabelOffset = 10;
			lineChart.XAxes[0].Labels = xLabelData;
            lineChart.XAxes[0].HorLabelAlignment = HorizontalAlignment.Center;
            lineChart.XAxes[0].LabelStroke = Brushes.White;






			//barChart
			barChart.TitleVisibility = Visibility.Collapsed;
			barChart.Series.Clear();
			BarSeries barSeries = new BarSeries()
            {
                Fills = new BrushCollection(),
                Strokes = new BrushCollection(),                
            };
            barSeries.Effect = new DropShadowEffect() { Opacity = 0.5, ShadowDepth = 3, };


            for (int i = 0; i < 10; i++)
            {
                LinearGradientBrush b = Utilities.GetGradientFills()[3] as LinearGradientBrush;
                Color light = b.GradientStops[0].Color;
                Color dark = b.GradientStops[1].Color;
                VisualBrush brush = Utilities.CreateVisualBrush(
                    dark, light, new SolidColorBrush(dark), 4, Orientation.Vertical, 4);
                barSeries.Fills.Add(brush);
            }
            barSeries.StrokeThickness = 0;
			barSeries.XData = xbarData;
			barSeries.YData = ybarData;
			barSeries.InnerLabel = xLabelData;
			barSeries.InnerLabelType = LabelType.CustomText;
			barSeries.TopLabel = xLabelData;
			barSeries.TopLabelType = LabelType.CustomText;
            barSeries.LabelForeground = Brushes.White;
			barChart.Series.Add(barSeries);			

			//barChart.YAxisSettings
            barChart.YAxes[0].Interval = 20;
            barChart.YAxes[0].LabelType = LabelType.AutoScale;
            barChart.YAxes[0].MinValue = 0;
            barChart.YAxes[0].MaxValue = 100;
            barChart.YAxes[0].Title = "";
            barChart.YAxes[0].LabelOffset = 10;
            barChart.YAxes[0].VertLabelAlignment = VerticalAlignment.Center;
            barChart.YAxes[0].LabelStroke = Brushes.White;
            

			//barChart.XAxisSettings
            barChart.XAxes[0].Interval = 6;
            barChart.XAxes[0].LabelType = LabelType.CustomText;
            barChart.XAxes[0].MinValue = 0;
            barChart.XAxes[0].MaxValue = 60;
            barChart.XAxes[0].Title = "";
            barChart.XAxes[0].LabelOffset = 10;
			barChart.XAxes[0].Labels = xLabelData;
            barChart.XAxes[0].HorLabelAlignment = HorizontalAlignment.Center;
            barChart.XAxes[0].LabelStroke = Brushes.White;



			innerLabelType.SelectedIndex = 0;
			topLabelType.SelectedIndex = 3;
			//labelType.SelectedIndex = 0;
			checkBox.IsChecked = true;

            VisualBrush fb1 = Utilities.CreateVisualBrush(
            Colors.Gray, Colors.White, new SolidColorBrush(Colors.Gray), 0, Orientation.Horizontal, 0);
            fb1.Opacity = 0.2;

            lineChart.GridFills.Add(fb1);
            barChart.GridFills.Add(fb1);

            lineChart.EndInit();
            barChart.EndInit();
		}

		private void labelType_SelectionChanged(object sender, SelectionChangedEventArgs e)
		{
			//LineSeries lineSeries = lineChart.Series[0] as LineSeries;			
			//if (labelType.SelectedIndex == 0)
			//    lineSeries.Labels = yData;
			//if (labelType.SelectedIndex == 1)
			//    lineSeries.Labels = xLabelData;
			//if (labelType.SelectedIndex == 2)
			//    lineSeries.Labels = new List<double>();
		}

		private void innerLabelType_SelectionChanged(object sender, SelectionChangedEventArgs e)
		{
			BarSeries barSeries = barChart.Series[0] as BarSeries;			
			if (innerLabelType.SelectedIndex == 0)
				barSeries.InnerLabelType = LabelType.ChartData;
			if (innerLabelType.SelectedIndex == 1)
				barSeries.InnerLabelType = LabelType.CustomText;
			if (innerLabelType.SelectedIndex == 2)
				barSeries.InnerLabelType = LabelType.Empty;
			if (innerLabelType.SelectedIndex == 3)
				barSeries.InnerLabelType = LabelType.Percents;
		}

		private void topLabelType_SelectionChanged(object sender, SelectionChangedEventArgs e)
		{
			BarSeries barSeries = barChart.Series[0] as BarSeries;			
			if (topLabelType.SelectedIndex == 0)
				barSeries.TopLabelType = LabelType.ChartData;
			if (topLabelType.SelectedIndex == 1)
				barSeries.TopLabelType = LabelType.CustomText;
			if (topLabelType.SelectedIndex == 2)
				barSeries.TopLabelType = LabelType.Empty;
			if (topLabelType.SelectedIndex == 3)
				barSeries.TopLabelType = LabelType.Percents;
		}

		private void CheckBox_Checked(object sender, RoutedEventArgs e)
		{
			LineSeries lineSeries = lineChart.Series[0] as LineSeries;
			lineSeries.Labels = yData;		
		}

		private void CheckBox_Unchecked(object sender, RoutedEventArgs e)
		{
			LineSeries lineSeries = lineChart.Series[0] as LineSeries;
			lineSeries.Labels = new List<double>();
		}

        private void Border_SizeChanged(object sender, SizeChangedEventArgs e)
        {
            Window1.OnBackPanelSizeChanged(sender);
        }
	}
}
