﻿using System;
using System.Collections.Generic;
using System.Linq;
using System.Text;
using System.Windows;
using System.Windows.Controls;
using System.Windows.Data;
using System.Windows.Documents;
using System.Windows.Input;
using System.Windows.Media;
using System.Windows.Media.Imaging;
using System.Windows.Navigation;
using System.Windows.Shapes;
using System.Collections;
using MindFusion.Charting.Wpf;
using System.Windows.Media.Effects;

namespace Demo
{
    /// <summary>
    /// Interaction logic for LineTypes.xaml
    /// </summary>
    public partial class LineTypes : UserControl
    {
        BrushCollection scatterFills;
        BrushCollection scatterStrokes;
		List<ScatterType> scatterTypes;
        DropShadowEffect effect;

        public LineTypes()
        {
            InitializeComponent();
			effect = new DropShadowEffect() { Opacity = 0.3, ShadowDepth = 3, };
            effect.Freeze();
            scatterFills = Utilities.GetGradientStrokes();
            scatterStrokes = Utilities.GetGradientFills();
            scatterTypes = new List<ScatterType>(4);
            scatterTypes.Add(ScatterType.Triangle);
            scatterTypes.Add(ScatterType.Diamond);
            scatterTypes.Add(ScatterType.Square);
            scatterTypes.Add(ScatterType.InvertedTriangle);

			// Generate the data
			Random r = new Random();

			_lineChart.Title = "";
            _lineChart.XAxes[0].MaxValue = double.NaN;
            _lineChart.XAxes[0].MinValue = 0;
            _lineChart.XAxes[0].Title = "";
            _lineChart.XAxes[0].LabelType = LabelType.Empty;

            _lineChart.YAxes[0].MaxValue = 80;
            _lineChart.YAxes[0].MinValue = 0;
            _lineChart.YAxes[0].Title = "";
            _lineChart.YAxes[0].Interval = 10;
            _lineChart.YAxes[0].LabelType = LabelType.AutoScale;
			_lineChart.Series.Clear();


            _lineChart.GridFills.Add(Brushes.Transparent);
            _lineChart.XAxes[0].LabelStroke = Brushes.White;
            _lineChart.YAxes[0].LabelStroke = Brushes.White;
            _lineChart.XAxes[0].TitleStroke = Brushes.White;
            _lineChart.YAxes[0].TitleStroke = Brushes.White;
            _lineChart.YAxes[0].LabelFormat = "0.##";
            _lineChart.YAxes[0].LabelOffset = 10;
            _lineChart.XAxes[0].LabelFormat = "0.##";
            _lineChart.YAxes[0].TitleOffset = 10;
            _lineChart.YAxes[0].VertLabelAlignment = VerticalAlignment.Center;
            _lineChart.YAxes[0].HorLabelAlignment = HorizontalAlignment.Left;
            _lineChart.XAxes[0].VertLabelAlignment = VerticalAlignment.Bottom;
            _lineChart.XAxes[0].HorLabelAlignment = HorizontalAlignment.Center;
            //_lineChart.Effect = effect;
            _lineChart.LineType = LineType.Area2D;

			for (int i = 0; i < 4; i++)
			{
				LineSeries series = new LineSeries();
                series.Effect = effect;
                for (int j = 0; j < 11; j++)
                {
                    double ampl = r.NextDouble() * 4 + 10;
                    if (r.NextDouble() > 0.70)
                        ampl = r.NextDouble() * 12 + 10; // Jump
                    ampl += (3 - i) * 2;
                    series.YData.Add(ampl);
                    series.XData.Add(j);
                }


                LinearGradientBrush b = scatterStrokes[i] as LinearGradientBrush;
                Color light = b.GradientStops[0].Color;
                Color dark = b.GradientStops[1].Color;
                VisualBrush brush = Utilities.CreateVisualBrush(
                    dark, light, new SolidColorBrush(dark), 0, Orientation.Horizontal, 0);
                //brush.Viewport = new Rect(0, 0, 100, 100);
                //brush.ViewportUnits = BrushMappingMode.Absolute;
                //brush.Viewbox = new Rect(0, 0, 5, 100);
                //brush.ViewboxUnits = BrushMappingMode.Absolute;
                //brush.TileMode = TileMode.Tile;
                //brush.Stretch = Stretch.None;
                series.Fills.Add(brush);
                series.Strokes.Add(new SolidColorBrush(dark));
                series.StrokeThickness = 4;           
                series.ScatterFills.Add(brush);
                series.ScatterStrokes.Add(scatterFills[i]);
                series.ScatterStrokeThickness = 1;
                series.ScatterSize = 15.0;

				_lineChart.Series.Add(series);
			}
		
			//_lineChart.UpdateChart();

            for (int i = 0; i < 4; i++)
                (_lineChart.Series[i] as LineSeries).ScatterType = ScatterType.None;
            //_lineChart.UpdateChart();
			cbLineType.SelectedIndex = 0;  
        }  

		private void setSelectedLineType()
		{
			for (int i = 0; i < 4; i++)
			{
				switch (cbLineType.SelectedIndex)
				{
					case 0:
						_lineChart.LineType = LineType.Area2D;
						break;
					case 1:
						_lineChart.LineType = LineType.Area2DStack;
						break;
					case 2:
						_lineChart.LineType = LineType.Line;
						break;				
				}
			}
		}

		private void CheckBox_Checked(object sender, RoutedEventArgs e)
		{
            string s = (sender as CheckBox).Name;
            if (s == "cbCurve")
            {
                for (int i = 0; i < _lineChart.Series.Count; i++)
                {
                    (_lineChart.Series[i] as LineSeries).Curve = true;
                }
            }
            else
            {
                for (int i = 0; i < _lineChart.Series.Count; i++)
                {
                    (_lineChart.Series[i] as LineSeries).ScatterType = scatterTypes[i];
                }
            }
		}

        private void CheckBox_Unchecked(object sender, RoutedEventArgs e)
		{
             string s = (sender as CheckBox).Name;
             if (s == "cbCurve")
             {
                 for (int i = 0; i < _lineChart.Series.Count; i++)
                 {
                     (_lineChart.Series[i] as LineSeries).Curve = false;
                 }
             }
             else
             {
                 for (int i = 0; i < _lineChart.Series.Count; i++)
                 {
                     (_lineChart.Series[i] as LineSeries).ScatterType = ScatterType.None;
                 }
             }
		}

		private void cbLineType_SelectionChanged(object sender, SelectionChangedEventArgs e)
		{
            if (_lineChart == null)
                return;

            setSelectedLineType();           
		}

        private void Grid_SizeChanged(object sender, SizeChangedEventArgs e)
        {
            Window1.OnBackPanelSizeChanged(sender);
        }

        private void ComboBox_DropDownOpened(object sender, EventArgs e)
        {
            ((sender as ComboBox).Items[0] as ComboBoxItem).Visibility = Visibility.Collapsed;
        }

        private void ComboBox_DropDownClosed(object sender, EventArgs e)
        {
            ((sender as ComboBox).Items[0] as ComboBoxItem).Visibility = Visibility.Visible;
        }
    }
}
