﻿using System;
using System.Collections.Generic;
using System.Linq;
using System.Text;
using System.Windows;
using System.Windows.Controls;
using System.Windows.Data;
using System.Windows.Documents;
using System.Windows.Input;
using System.Windows.Media;
using System.Windows.Media.Imaging;
using System.Windows.Navigation;
using System.Windows.Shapes;
using MindFusion.Charting.Wpf;
using System.Windows.Media.Effects;

namespace Demo
{
	/// <summary>
	/// Interaction logic for MultipleSeries.xaml
	/// </summary>
	public partial class MultipleSeries : UserControl
	{
		private List<BarSeries> barSeries;
		private List<LineSeries> lineSeries;
		private int count = 0;
        private BrushCollection Fills;
        private BrushCollection Strokes;

		public MultipleSeries()
		{
			InitializeComponent();
			Fills = Utilities.GetGradientFills();
			Strokes = Utilities.GetGradientStrokes();

			lineChart1.Title = "";
			barSeries = new List<BarSeries>();
			lineSeries = new List<LineSeries>();

            barChart3D1.SideWallThickness = 0.5;
			barChart3D1.ModelWidth = 120;
			barChart3D1.ModelHeight = 40;
			barChart3D1.RotationAngle = 0;
			barChart3D1.Scale = 180;
            barChart3D1.YAxisSettings.LabelOffset = 3;
            barChart3D1.ModelDepth = 20;

            barChart3D1.GridFills = new List<Brush>();
            Brush brush = new SolidColorBrush(Color.FromArgb(25, 255, 255, 255));
            barChart3D1.GridFills.Add(brush);
            barChart3D1.YAxisSettings.LabelStroke = Brushes.White;
            //barChart3D1.YAxisSettings.MinValue = -0.1;
            lineChart1.GridFills.Add(brush);
            lineChart1.YAxes[0].LabelStroke = Brushes.White;
            lineChart1.YAxes[0].VertLabelAlignment = VerticalAlignment.Center;
			AddSeries();			
		}

		private void AddSeries()
		{
			if (lineChart1 == null)
				return;

			Random r = new Random();
            DoubleCollection xData = new DoubleCollection() { 1, 2, 3, 4, 5, 6 };
            DoubleCollection yData = new DoubleCollection();
			for (int i = 0; i < xData.Count; i++)
			{
				int j = r.Next(100);
				if (j <= 100)
					yData.Add(r.NextDouble() * 25 + 10);
				else
					yData.Add(-r.NextDouble() * 25 + 10);
			}

            BarSeries series = new BarSeries()
            {
                Fills = new BrushCollection(),
                Strokes = new BrushCollection(),
            };
			series.Fills.Add(Fills[count]);
			series.Strokes.Add(Strokes[count]);

			LineSeries series2 = new LineSeries()
            {
                Fills = new BrushCollection(),
                Strokes = new BrushCollection(),
                ScatterFills = new BrushCollection(),
                ScatterStrokes = new BrushCollection(),
            };
			//series2.Fills.Add(Fills[count]);
			//series2.Strokes.Add(Strokes[count]);
            Brush b = Utilities.GetGradientFills()[count];
            Color color = (b as LinearGradientBrush).GradientStops[1].Color;
            b = Window1.TransformBrush(b, 255);
            b.Opacity = 0.7;
			series2.Fills.Add(b);
            series2.Strokes.Add(new SolidColorBrush(color));
            series2.StrokeThickness = 3;


			count += 1;
			if (count == 8)
				count = 0;

			series.XData = xData;
			series.YData = yData;
			series2.XData = xData;
			series2.YData = yData;

			barSeries.Add(series);
			lineSeries.Add(series2);

			UpdateBarChart();
		}

		private void UpdateBarChart()
		{
			if (lineChart1 == null || barChart3D1 == null)
				return;

			barChart3D1.BeginInit();

			//set setings
			lineChart1.YAxes[0].Interval = 10;
            lineChart1.YAxes[0].Title = "";
            lineChart1.YAxes[0].LabelType = LabelType.AutoScale;

            lineChart1.XAxes[0].LabelType = LabelType.Empty;
            lineChart1.XAxes[0].Interval = 1.0;
            lineChart1.XAxes[0].Title = "";

			if (cbHorizontal.IsChecked == true)
			{
				//lineChart1.XAxisSettings.Interval = 10;
				//lineChart1.XAxisSettings.Title = "";
				//lineChart1.XAxisSettings.LabelType = LabelType.AutoScale;

				//lineChart1.YAxisSettings.LabelType = LabelType.Empty;
				//lineChart1.YAxisSettings.Interval = 1.0;
				//lineChart1.YAxisSettings.Title = "";


                barChart3D1.XAxisSettings.Interval = 10;
                barChart3D1.XAxisSettings.Title = "";
                barChart3D1.XAxisSettings.LabelType = LabelType.AutoScale;

                barChart3D1.YAxisSettings.LabelType = LabelType.Empty;
                barChart3D1.XAxisSettings.Interval = 1.0;
                barChart3D1.XAxisSettings.Title = "";				
			}
			else
			{
				//lineChart1.YAxisSettings.Interval = 10;
				//lineChart1.YAxisSettings.Title = "";
				//lineChart1.YAxisSettings.LabelType = LabelType.AutoScale;

				//lineChart1.XAxisSettings.LabelType = LabelType.Empty;
				//lineChart1.XAxisSettings.Interval = 1.0;
				//lineChart1.XAxisSettings.Title = "";


                barChart3D1.YAxisSettings.Interval = 10;
                barChart3D1.YAxisSettings.Title = "";
                barChart3D1.YAxisSettings.LabelType = LabelType.AutoScale;

                barChart3D1.XAxisSettings.LabelType = LabelType.Empty;
                barChart3D1.XAxisSettings.Interval = 1.0;
                barChart3D1.XAxisSettings.Title = "";				
			}
			

			//set series
			lineChart1.Series.Clear();
			barChart3D1.Series.Clear();
			for (int i = 0; i < barSeries.Count; i++)
			{
				BarSeries s = barSeries[i];
				LineSeries s2 = lineSeries[i];

                BarSeries series = new BarSeries()
                {
                    Fills = new BrushCollection(),
                    Strokes = new BrushCollection(),
                };
                series.Effect = new DropShadowEffect() { Opacity = 0.3, ShadowDepth = 3, };
				series.Fills.Add(s.Fills[0]);
				series.Strokes.Add(s.Strokes[0]);

				LineSeries series2 = new LineSeries()
                {
                    Fills = new BrushCollection(),
                    Strokes = new BrushCollection(),
                    ScatterFills = new BrushCollection(),
                    ScatterStrokes = new BrushCollection(),
                };
                series2.Effect = new DropShadowEffect() { Opacity = 0.3, ShadowDepth = 3, };
				series2.Fills.Add(s2.Fills[0]);
				series2.Strokes.Add(s2.Strokes[0]);
                series2.StrokeThickness = s2.StrokeThickness;
				lineChart1.Series.Add(series2);
				barChart3D1.Series.Add(series);

				series.XData = s.XData;
				series.YData = s.YData;

				series2.XData = s2.XData;
				series2.YData = s2.YData;
                lineChart1.LineType = LineType.Area2D;
                lineChart1.YAxes[0].MinValue = 0;
                lineChart1.XAxes[0].MinValue = 1;

				if (cbHorizontal.IsChecked == true)
				{
					series.XData = s.YData;
					series.YData = s.XData;

					//series2.XData = s2.YData;
					//series2.YData = s2.XData;
					//series2.LineType = LineType.Area2D;
					//lineChart1.YAxisSettings.MinValue = 1;
					//lineChart1.XAxisSettings.MinValue = 0;

					if (cbBarType.SelectedIndex == 0)
					{
                        lineChart1.BarType = BarType.Horizontal;
						barChart3D1.BarType3D = BarType3D.Horizontal;
					}
					else if (cbBarType.SelectedIndex == 1)
					{
                        lineChart1.BarType = BarType.HorizontalOverlay;
						barChart3D1.BarType3D = BarType3D.HorizontalInColumn;
					}
					else if (cbBarType.SelectedIndex == 2)
					{
                        lineChart1.BarType = BarType.HorizontalStack;
						barChart3D1.BarType3D = BarType3D.HorizontalStack;
					}
				}
				else
				{
					if (cbBarType.SelectedIndex == 0)
					{
                        lineChart1.BarType = BarType.Vertical;
						barChart3D1.BarType3D = BarType3D.Vertical;
					}
					else if (cbBarType.SelectedIndex == 1)
					{
                        lineChart1.BarType = BarType.VerticalOverlay;
						barChart3D1.BarType3D = BarType3D.VerticalInColumn;
					}
					else if (cbBarType.SelectedIndex == 2)
					{
                        lineChart1.BarType = BarType.VerticalStack;
						barChart3D1.BarType3D = BarType3D.VerticalStack;
					}
				}
			}

			lineChart1.UpdateChart();
			barChart3D1.EndInit();
		}

		private void cbHorizontal_Checked(object sender, RoutedEventArgs e)
		{
			UpdateBarChart();
		}

		private void cbHorizontal_Unchecked(object sender, RoutedEventArgs e)
		{
			UpdateBarChart();
		}

		private void cbLineType_SelectionChanged(object sender, SelectionChangedEventArgs e)
		{
			UpdateBarChart();
		}

		private void Button_Click(object sender, RoutedEventArgs e)
		{
			AddSeries();	
		}

        private void Border_SizeChanged(object sender, SizeChangedEventArgs e)
        {
            Window1.OnBackPanelSizeChanged(sender);
        }

        private void ComboBox_DropDownOpened(object sender, EventArgs e)
        {
            ((sender as ComboBox).Items[0] as ComboBoxItem).Visibility = Visibility.Collapsed;
        }

        private void ComboBox_DropDownClosed(object sender, EventArgs e)
        {
            ((sender as ComboBox).Items[0] as ComboBoxItem).Visibility = Visibility.Visible;
        }

        private void chartGrid_SizeChanged(object sender, SizeChangedEventArgs e)
        {
            
        }
	}
}
