﻿using System;
using System.Collections.Generic;
using System.Linq;
using System.Text;
using System.Windows;
using System.Windows.Controls;
using System.Windows.Data;
using System.Windows.Documents;
using System.Windows.Input;
using System.Windows.Media;
using System.Windows.Media.Imaging;
using System.Windows.Navigation;
using System.Windows.Shapes;
using MindFusion.Charting.Wpf;
using System.Windows.Media.Effects;

namespace Demo
{
	/// <summary>
	/// Interaction logic for PieChart.xaml
	/// </summary>
	public partial class PieChart : UserControl
	{
		public PieChart()
		{
			InitializeComponent();
			pieChart.TitleVisibility = Visibility.Collapsed;

			DoubleCollection data = new DoubleCollection() {
				35, 16, 28.32, 45, 19, 33, 28.6, 16.92, 42.12, 5.05, 9.16, 8.33,
			};
			List<string> customLabels = new List<string>(new string[] {
			    "Jan", "Feb", "Mar", "Apr", "May", "Jun",
				"Jul", "Aug", "Sep", "Oct", "Nov", "Dec",
			});


			PieSeries series = new PieSeries();
            series.Effect = new DropShadowEffect() { Opacity = 0.5, ShadowDepth = 3, };
			series.Data = data;
			series.PieType = PieType.Pie2D;
			series.InnerLabel = customLabels;		
			series.OuterLabel = customLabels;
            series.LabelForeground = Brushes.White;
			series.OuterLabelOffset = 30;

			//series.Fills.Add(Brushes.LightGreen);
			//series.Fills.Add(Brushes.DodgerBlue);
			//series.Fills.Add(Brushes.Violet);
			//series.Fills.Add(Brushes.Yellow);
			//series.Fills.Add(Brushes.PowderBlue);
			//series.Fills.Add(Brushes.BurlyWood);
			//series.Fills.Add(Brushes.Tomato);
			//series.Fills.Add(Brushes.Orange);

			//series.Strokes.Add(Brushes.Green);
			//series.Strokes.Add(Brushes.Blue);
			//series.Strokes.Add(Brushes.BlueViolet);
			//series.Strokes.Add(Brushes.Orange);
			//series.Strokes.Add(Brushes.CadetBlue);
			//series.Strokes.Add(Brushes.Brown);
			//series.Strokes.Add(Brushes.Red);
			//series.Strokes.Add(Brushes.OrangeRed);

            for (int i = 0; i < 8; i++)
                series.Fills.Add(Window1.TransformBrush(Utilities.GetGradientFills()[i], 255));

			//series.Fills = Utilities.GetGradientStrokes();
            series.Strokes = Utilities.GetGradientStrokes();

			//series.Fills.Add(Brushes.Violet);
			//series.Strokes.Add(Brushes.BlueViolet);


			pieChart.Series.Clear();
			pieChart.Series.Add(series);


			innerLabelType.SelectedIndex = 1;
			outerLabelType.SelectedIndex = 0;
			slider.Value = series.InnerLabelLocation;
            pieChart.PlotAreaMargin = new Thickness(40, 20, 40, 20);
			//outerSlider.Value = series.OuterLabelOffset;
		}

		private void innerLabelType_SelectionChanged(object sender, SelectionChangedEventArgs e)
		{
			PieSeries pieSeries = pieChart.Series[0] as PieSeries;
			if (innerLabelType.SelectedIndex == 0)
				pieSeries.InnerLabelType = LabelType.ChartData;
			if (innerLabelType.SelectedIndex == 1)
				pieSeries.InnerLabelType = LabelType.CustomText;
			if (innerLabelType.SelectedIndex == 2)
				pieSeries.InnerLabelType = LabelType.Empty;
			if (innerLabelType.SelectedIndex == 3)
				pieSeries.InnerLabelType = LabelType.Percents;
		}

		private void outerLabelType_SelectionChanged(object sender, SelectionChangedEventArgs e)
		{
			PieSeries pieSeries = pieChart.Series[0] as PieSeries;
			if (outerLabelType.SelectedIndex == 0)
				pieSeries.OuterLabelType = LabelType.ChartData;
			if (outerLabelType.SelectedIndex == 1)
				pieSeries.OuterLabelType = LabelType.CustomText;
			if (outerLabelType.SelectedIndex == 2)
				pieSeries.OuterLabelType = LabelType.Empty;
			if (outerLabelType.SelectedIndex == 3)
				pieSeries.OuterLabelType = LabelType.Percents;
		}

		private void slider_ValueChanged(object sender, RoutedPropertyChangedEventArgs<double> e)
		{
			PieSeries pieSeries = pieChart.Series[0] as PieSeries;
			pieSeries.InnerLabelLocation = slider.Value;
		}

		private void outerSlider_ValueChanged(object sender, RoutedPropertyChangedEventArgs<double> e)
		{
			//PieSeries pieSeries = pieChart.Series[0] as PieSeries;
			//pieSeries.OuterLabelOffset = outerSlider.Value;
		}

        private void Border_SizeChanged(object sender, SizeChangedEventArgs e)
        {
            Window1.OnBackPanelSizeChanged(sender);
        }

        private void ComboBox_DropDownOpened(object sender, EventArgs e)
        {
            ((sender as ComboBox).Items[0] as ComboBoxItem).Visibility = Visibility.Collapsed;
        }

        private void ComboBox_DropDownClosed(object sender, EventArgs e)
        {
            ((sender as ComboBox).Items[0] as ComboBoxItem).Visibility = Visibility.Visible;
        }
	}
}
