﻿using System;
using System.Collections.Generic;
using System.Linq;
using System.Text;
using System.Windows;
using System.Windows.Controls;
using System.Windows.Data;
using System.Windows.Documents;
using System.Windows.Input;
using System.Windows.Media;
using System.Windows.Media.Imaging;
using System.Windows.Navigation;
using System.Windows.Shapes;
using MindFusion.Charting.Wpf;
using System.Windows.Media.Effects;

namespace Demo
{
    /// <summary>
    /// Interaction logic for RadarChart.xaml
    /// </summary>
    public partial class RadarChart : UserControl
    {
        BrushCollection brushes = Utilities.GetGradientFills();
        BrushCollection strokes = Utilities.GetGradientStrokes();
        BrushCollection brushesTrans = Utilities.GetGradientFills(false, 200);


        public RadarChart()
        {
            InitializeComponent();



            double scaterSize = 15;

            radarChart.Series.Clear();



            //Serie 1
            RadarSeries serie1 = new RadarSeries()
            {
                Fills = new BrushCollection(),
                Strokes = new BrushCollection(),
                RadarScatterFills = new BrushCollection(),
                RadarScatterStrokes = new BrushCollection(),
            };
            serie1.Effect = new DropShadowEffect() { Opacity = 0.5, ShadowDepth = 3, };
            serie1.Data = new DoubleCollection() { 40, 60, 90, 160, 120, 116 };
            Brush fill1 = brushes[brushes.Count - 1];
            Brush fillTransparent1 = brushesTrans[brushesTrans.Count - 1];
            Brush stroke1 = strokes[strokes.Count - 1];
            serie1.Fills.Add(Window1.TransformBrush(fillTransparent1, 170));
            serie1.Fills[0].Opacity = 0.7;
            serie1.Strokes.Add(new SolidColorBrush((fillTransparent1 as LinearGradientBrush).GradientStops[1].Color));
            serie1.Strokes[0].Opacity = 0.7;
            serie1.StrokeThickness = 4;
            serie1.LabelBackground = Window1.TransformBrush(fill1, 170);
            serie1.LabelBorderBrush = stroke1;
            serie1.LabelForeground = Brushes.White;
            serie1.RadarScatterFills.Add(Window1.TransformBrush(fillTransparent1, 170));
            serie1.RadarScatterStrokes.Add(stroke1);
            serie1.ScatterSize = scaterSize;
            serie1.Labels = new string[] { "Data 1", "Data 2", "Data 3", "Data 4", "Data 5", "Data 6" };
            serie1.LabelOffset = 30;
            radarChart.Series.Add(serie1);


            //Serie2
            RadarSeries serie2 = new RadarSeries()
            {
                Fills = new BrushCollection(),
                Strokes = new BrushCollection(),
                RadarScatterFills = new BrushCollection(),
                RadarScatterStrokes = new BrushCollection(),
            };
            serie2.Effect = new DropShadowEffect() { Opacity = 0.5, ShadowDepth = 3, };
            serie2.Data = new DoubleCollection() { 154, 155, 130, 92, 46, 60 };
            Brush fill2 = brushes[brushes.Count - 2];
            Brush fillTransparent2 = brushesTrans[brushesTrans.Count - 2];
            Brush stroke2 = strokes[strokes.Count - 2];
            serie2.Fills.Add(Window1.TransformBrush(fillTransparent2,170));
            serie2.Fills[0].Opacity = 0.7;
            serie2.Strokes.Add(new SolidColorBrush((fillTransparent2 as LinearGradientBrush).GradientStops[1].Color));
            serie2.Strokes[0].Opacity = 0.7;
            serie2.StrokeThickness = 4;
            serie2.LabelBackground = Window1.TransformBrush(fill2, 170);

            serie2.LabelBorderBrush = stroke2;
            serie2.LabelForeground = Brushes.White;
            serie2.RadarScatterFills.Add(Window1.TransformBrush(fillTransparent2, 170));
            serie2.RadarScatterStrokes.Add(stroke2);
            serie2.ScatterSize = scaterSize;
            serie2.Labels = new string[] { "Data 1", "Data 2", "Data 3", "Data 4", "Data 5", "Data 6" };
            serie2.LabelOffset = 30;
            radarChart.Series.Add(serie2);


            radarChart.TitleVisibility = Visibility.Collapsed;
            radarChart.MinValue = 0;
            radarChart.MaxValue = 200;
            radarChart.Interval = 40;
            radarChart.InnerLabelOffset = 0.15;
            radarChart.OuterStrokeDashArray = null;
            radarChart.InnerStrokeDashArray = null;
            radarChart.OuterLabelBackground = null;
            radarChart.OuterLabelBorderThickness = new Thickness(0);
            radarChart.OuterLabels = new string[] {"January", "February", "March", "April", "May", "June"};
            radarChart.InnerLabels = new string[] { "$1000", "$2000", "$3000", "$4000", "$5000", "$6000" };
            radarChart.RadarType = RadarType.Radar;
            radarChart.InnerLabelBackground = Brushes.White;
            radarChart.InnerLabelBorderBrush = Brushes.Black;
            radarChart.InnerLabelBorderThickness = new Thickness(1);
            radarChart.UpdateChart();

            this.Loaded += new RoutedEventHandler(RadarChart_Loaded);


            VisualBrush fb1 = Utilities.CreateVisualBrush(
            Colors.Gray, Colors.White, new SolidColorBrush(Colors.Gray), 0, Orientation.Horizontal, 0);
            fb1.Opacity = 0.2;

            radarChart.SectionBrushes = new List<Brush>();
            radarChart.SectionBrushes.Add(fb1);
            radarChart.SectionBrushes.Add(Brushes.Transparent);
            radarChart.SectionBrushes.Add(Brushes.Transparent);
            radarChart.SectionBrushes.Add(Brushes.Transparent);
            radarChart.SectionBrushes.Add(Brushes.Transparent);

            radarChart.OuterStrokeThickness = 1;
            radarChart.OuterAxisStroke = new SolidColorBrush(Color.FromArgb(255, 220, 220, 220));
            radarChart.OuterLabelForeground = Brushes.White;
            radarChart.OuterLabelOffset = 25;
        }

        void RadarChart_Loaded(object sender, RoutedEventArgs e)
        {
            SeriesLabelType.SelectedIndex = 3;
            SeriesLabelType.SelectedIndex = 0;
        }

        private void OuterLabelType_SelectionChanged(object sender, SelectionChangedEventArgs e)
        {
            if (radarChart == null)
                return;

            ComboBox box = sender as ComboBox;
            if (box.SelectedIndex == 0)
                radarChart.OuterLabelType = LabelType.AutoScale;
            if (box.SelectedIndex == 1)
                radarChart.OuterLabelType = LabelType.CustomText;
            if (box.SelectedIndex == 2)
                radarChart.OuterLabelType = LabelType.Percents;
            if (box.SelectedIndex == 3)
                radarChart.OuterLabelType = LabelType.Empty;

            //radarChart.UpdateChart();
        }

        private void InnerLabelType_SelectionChanged(object sender, SelectionChangedEventArgs e)
        {
            if (radarChart == null)
                return;

            ComboBox box = sender as ComboBox;
            if (box.SelectedIndex == 0)
                radarChart.InnerLabelType = LabelType.AutoScale;
            if (box.SelectedIndex == 1)
                radarChart.InnerLabelType = LabelType.CustomText;
            if (box.SelectedIndex == 2)
                radarChart.InnerLabelType = LabelType.Percents;
            if (box.SelectedIndex == 3)
                radarChart.InnerLabelType = LabelType.Empty;

            //radarChart.UpdateChart();
        }

        private void SeriesLabelType_SelectionChanged(object sender, SelectionChangedEventArgs e)
        {
            if (radarChart == null)
                return;

            ComboBox box = sender as ComboBox;
            foreach (ChartSeries s in radarChart.Series)
            {
                if (s is RadarSeries)
                {
                    RadarSeries serie = s as RadarSeries;
                    if (box.SelectedIndex == 0)
                        serie.LabelType = LabelType.ChartData;
                    if (box.SelectedIndex == 1)
                        serie.LabelType = LabelType.CustomText;
                    if (box.SelectedIndex == 2)
                        serie.LabelType = LabelType.Percents;
                    if (box.SelectedIndex == 3)
                        serie.LabelType = LabelType.Empty;
                }
            }

            //radarChart.UpdateChart();
        }

        private void OuterSlider_ValueChanged(object sender, RoutedPropertyChangedEventArgs<double> e)
        {
            if (radarChart == null)
                return;

            Slider slider = sender as Slider;
            radarChart.OuterLabelOffset = slider.Value;            
            //radarChart.UpdateChart();
        }

        private void InnerSlider_ValueChanged(object sender, RoutedPropertyChangedEventArgs<double> e)
        {
            if (radarChart == null)
                return;

            Slider slider = sender as Slider;
            radarChart.InnerLabelOffset = slider.Value;
            //radarChart.UpdateChart();
        }

        private void SeriesLabelSlider_ValueChanged(object sender, RoutedPropertyChangedEventArgs<double> e)
        {
            if (radarChart == null)
                return;

            Slider slider = sender as Slider;            
            foreach (ChartSeries s in radarChart.Series)
            {
                if (s is RadarSeries)
                    (s as RadarSeries).LabelOffset = slider.Value;
            }
            //radarChart.UpdateChart();
        }

        private void Border_SizeChanged(object sender, SizeChangedEventArgs e)
        {
            Window1.OnBackPanelSizeChanged(sender);
        }

        private void ComboBox_DropDownOpened(object sender, EventArgs e)
        {
            ((sender as ComboBox).Items[0] as ComboBoxItem).Visibility = Visibility.Collapsed;
        }

        private void ComboBox_DropDownClosed(object sender, EventArgs e)
        {
            ((sender as ComboBox).Items[0] as ComboBoxItem).Visibility = Visibility.Visible;
        }       
    }
}
