﻿using System;
using System.Collections.Generic;
using System.Linq;
using System.Text;
using System.Windows;
using System.Windows.Controls;
using System.Windows.Data;
using System.Windows.Documents;
using System.Windows.Input;
using System.Windows.Media;
using System.Windows.Media.Imaging;
using System.Windows.Navigation;
using System.Windows.Shapes;
using MindFusion.Charting.Wpf;
using System.Windows.Media.Effects;

namespace Demo
{
    /// <summary>
    /// Interaction logic for RadarTypes.xaml
    /// </summary>
    public partial class RadarTypes : UserControl
    {
        BrushCollection brushes = Utilities.GetGradientFills();
        BrushCollection strokes = Utilities.GetGradientStrokes();
        BrushCollection brushesTrans = Utilities.GetGradientFills();

        private VisualBrush TransformBrush(Brush transBrush, double opacity)
        {
            LinearGradientBrush b = transBrush as LinearGradientBrush;
            Color light = b.GradientStops[0].Color;
            Color dark = b.GradientStops[1].Color;
            VisualBrush brush = Utilities.CreateVisualBrush(
                dark, light, new SolidColorBrush(dark), 0, Orientation.Horizontal, 0);
            brush.Opacity = opacity;
            return brush;
        }

        private Brush TransparentBrush(Brush transBrush, double opacity)
        {
            Brush brush = (transBrush as Brush).Clone() as Brush;
            brush.Opacity = opacity;
            return brush;
        }

        private SolidColorBrush DarkBrush(Brush transBrush)
        {
            SolidColorBrush brush = (transBrush as SolidColorBrush).Clone() as SolidColorBrush;
            Color c = brush.Color;
            c.R -= 60;
            c.G -= 60;
            c.B -= 60;
            brush.Color = c;
            return brush;
        }

        public RadarTypes()
        {
            InitializeComponent();
            double scaterSize = 12;




            radarChart.Series.Clear();

            DropShadowEffect effect = new DropShadowEffect() { Opacity = 0.3, ShadowDepth = 3, };
            effect.Freeze();


            //Serie3
            RadarSeries serie3 = new RadarSeries()
            {
                Fills = new BrushCollection(),
                Strokes = new BrushCollection(),
                RadarScatterFills = new BrushCollection(),
                RadarScatterStrokes = new BrushCollection()
            };
            serie3.Effect = effect;
            serie3.Data = new DoubleCollection() { 50, 57, 85, 66, 80, 88 };

            Brush fill3 = TransformBrush(brushes[7], 1);
            Brush fillTransparent3 = TransformBrush(brushesTrans[7], 0.7);
            Brush stroke3 = new SolidColorBrush((brushes[7] as GradientBrush).GradientStops[1].Color);// strokes[7];

            serie3.Fills.Add(fillTransparent3);
            serie3.Strokes.Add(TransparentBrush(brushes[7], 1));
            serie3.Strokes[0].Opacity = 0.7;
            serie3.StrokeThickness = 4;
            serie3.LabelBackground = fill3;
            serie3.LabelBorderBrush = strokes[7];
            serie3.LabelForeground = Brushes.White;
            serie3.RadarScatterFills.Add(fill3);
            serie3.RadarScatterStrokes.Add(strokes[7]);
            serie3.ScatterSize = scaterSize;
            radarChart.Series.Add(serie3);


            //Serie 1
            RadarSeries serie1 = new RadarSeries()
            {
                Fills = new BrushCollection(),
                Strokes = new BrushCollection(),
                RadarScatterFills = new BrushCollection(),
                RadarScatterStrokes = new BrushCollection()
            };
            serie1.Effect = effect;
            serie1.Data = new DoubleCollection() { 20, 30, 45, 90, 60, 58 };
            Brush fill1 = TransformBrush(brushes[0],1);
            Brush fillTransparent1 = TransformBrush(brushesTrans[0], 0.8);
            Brush stroke1 = new SolidColorBrush((brushes[0] as GradientBrush).GradientStops[1].Color);// strokes[0];
            serie1.Fills.Add(fillTransparent1);
            serie1.Strokes.Add(TransparentBrush(brushes[0], 1));
            serie1.Strokes[0].Opacity = 0.7;
            serie1.StrokeThickness = 4;
            serie1.LabelBackground = fill1;
            serie1.LabelBorderBrush = strokes[0];
            serie1.LabelForeground = Brushes.White;
            serie1.RadarScatterFills.Add(fill1);
            serie1.RadarScatterStrokes.Add(strokes[0]);
            serie1.ScatterSize = scaterSize;
            serie1.LabelBorderThickness = new Thickness(1);
            radarChart.Series.Add(serie1);



            //Serie2
            RadarSeries serie2 = new RadarSeries()
            {
                Fills = new BrushCollection(),
                Strokes = new BrushCollection(),
                RadarScatterFills = new BrushCollection(),
                RadarScatterStrokes = new BrushCollection()                
            };
            serie2.Effect = effect;
            serie2.Data = new DoubleCollection() { 80, 90, 65, 46, 23, 30 };
            Brush fill2 = TransformBrush(brushes[1],1);
            Brush fillTransparent2 = TransformBrush(brushesTrans[1], 0.8);
            Brush stroke2 = new SolidColorBrush((brushes[1] as GradientBrush).GradientStops[1].Color);// strokes[1];
            serie2.Fills.Add(fillTransparent2);
            serie2.Strokes.Add(TransparentBrush(brushes[1], 1));
            serie2.Strokes[0].Opacity = 0.7;
            serie2.StrokeThickness = 4;
            serie2.LabelBackground = fill2;
            serie2.LabelBorderBrush = strokes[1];
            serie2.LabelForeground = Brushes.White;
            serie2.RadarScatterFills.Add(fill2);
            serie2.RadarScatterStrokes.Add(strokes[1]);
            serie2.ScatterSize = scaterSize;
            radarChart.Series.Add(serie2);





            radarChart.TitleVisibility = Visibility.Collapsed;
            radarChart.InnerLabelAngle = 90;
            radarChart.OuterStrokeDashArray = null;
            radarChart.InnerStrokeDashArray = null;

            radarChart.OuterLabelBackground = null;
            radarChart.OuterLabelForeground = Brushes.White;
            radarChart.OuterLabelBorderThickness = new Thickness(0);
            radarChart.OuterLabelOffset = 30;

            radarChart.InnerLabelBorderThickness = new Thickness(1);
            radarChart.InnerLabelBorderBrush = Brushes.Black;
            radarChart.InnerLabelBackground = Brushes.White;

            radarChart.OuterAxisStroke = Brushes.White;
            radarChart.InnerAxisStroke = Brushes.White;
            radarChart.SectionBrushes = new List<Brush>() {Brushes.Transparent };
            radarChart.SectionStrokes = new List<Brush>() { Brushes.White };

            VisualBrush fb1 = Utilities.CreateVisualBrush(
            Colors.Gray, Colors.White, new SolidColorBrush(Colors.Gray), 0, Orientation.Horizontal, 0);
            fb1.Opacity = 0.2;
            radarChart.SectionBrushes = new List<Brush>();
            radarChart.SectionBrushes.Add(fb1);
            radarChart.SectionBrushes.Add(Brushes.Transparent);
            radarChart.SectionBrushes.Add(Brushes.Transparent);
            radarChart.SectionBrushes.Add(Brushes.Transparent);
            radarChart.SectionBrushes.Add(Brushes.Transparent);


            radarChart.UpdateChart();


            this.Loaded += new RoutedEventHandler(RadarTypes_Loaded);
        }

        void RadarTypes_Loaded(object sender, RoutedEventArgs e)
        {
            cbLabels.IsChecked = true;
        }

        private void cbRadarType_SelectionChanged(object sender, SelectionChangedEventArgs e)
        {
            if (radarChart == null)
                return;

            ComboBox box = sender as ComboBox;
            foreach (ChartSeries s in radarChart.Series)
            {
                if (s is RadarSeries)
                {
                    RadarSeries serie = s as RadarSeries;
                    if (box.SelectedIndex == 0)
                    {
                        serie.RadarStyle = RadarStyle.Line;
                    }
                    if (box.SelectedIndex == 1)
                    {
                        serie.RadarStyle = RadarStyle.Arc;
                    }
                    if (box.SelectedIndex == 2)
                    {
                        serie.RadarStyle = RadarStyle.Bezier;
                    }
                }
            }

            //radarChart.UpdateChart();
        }

        private void cbArea_Checked(object sender, RoutedEventArgs e)
        {
            if (radarChart == null)
                return;

            for (int i = 0; i < radarChart.Series.Count; i++)
            {
                ChartSeries s = radarChart.Series[i];
                if (s is RadarSeries)
                {
                    RadarSeries serie = s as RadarSeries;
                    serie.Fills.Clear();
                    if (i == 0)
                        serie.Fills.Add(TransformBrush(brushesTrans[7], 0.8));   
                    if (i == 1)
                        serie.Fills.Add(TransformBrush(brushesTrans[0], 0.8));         
                    if (i == 2)
                        serie.Fills.Add(TransformBrush(brushesTrans[1], 0.8));         
                }
            }
            radarChart.UpdateChart();
        }

        private void cbArea_UnChecked(object sender, RoutedEventArgs e)
        {
            if (radarChart == null)
                return;

            for (int i = 0; i < radarChart.Series.Count; i++)
            {
                ChartSeries s = radarChart.Series[i];
                if (s is RadarSeries)
                {
                    RadarSeries serie = s as RadarSeries;
                    serie.Fills.Clear();
                    serie.Fills.Add(Brushes.Transparent);
                }
            }
            radarChart.UpdateChart();
        }



        private void cbScatters_Checked(object sender, RoutedEventArgs e)
        {
            if (radarChart == null)
                return;
            foreach (RadarSeries series in radarChart.Series)
                series.ScatterType = ScatterType.Circle;
        }

        private void cbScatters_UnChecked(object sender, RoutedEventArgs e)
        {
            if (radarChart == null)
                return;
            foreach (RadarSeries series in radarChart.Series)
                series.ScatterType = ScatterType.None;
        }

        private void sliderAngle_ValueChanged(object sender, RoutedPropertyChangedEventArgs<double> e)
        {
            if (radarChart == null)
                return;
            radarChart.StartAngle = (sender as Slider).Value;
        }

        private void sliderStep_ValueChanged(object sender, RoutedPropertyChangedEventArgs<double> e)
        {
            if (radarChart == null)
                return;
            radarChart.AngleStep = (int)(sender as Slider).Value;
        }

        private void cbLabels_Checked(object sender, RoutedEventArgs e)
        {
            if (radarChart == null)
                return;

            for (int i = 0; i < radarChart.Series.Count; i++)
            {
                ChartSeries s = radarChart.Series[i];
                if (s is RadarSeries)
                {
                    RadarSeries serie = s as RadarSeries;
                    serie.LabelType = LabelType.ChartData;                   
                }
            }
        }

        private void cbLabels_UnChecked(object sender, RoutedEventArgs e)
        {
            if (radarChart == null)
                return;

            for (int i = 0; i < radarChart.Series.Count; i++)
            {
                ChartSeries s = radarChart.Series[i];
                if (s is RadarSeries)
                {
                    RadarSeries serie = s as RadarSeries;
                    serie.LabelType = LabelType.Empty;
                }
            }
        }

        private void Border_SizeChanged(object sender, SizeChangedEventArgs e)
        {
            Window1.OnBackPanelSizeChanged(sender);
        }

        private void ComboBox_DropDownOpened(object sender, EventArgs e)
        {
            ((sender as ComboBox).Items[0] as ComboBoxItem).Visibility = Visibility.Collapsed;
        }

        private void ComboBox_DropDownClosed(object sender, EventArgs e)
        {
            ((sender as ComboBox).Items[0] as ComboBoxItem).Visibility = Visibility.Visible;
        }
    }
}
