﻿using System;
using System.Collections.Generic;
using System.Linq;
using System.Text;
using System.Windows;
using System.Windows.Controls;
using System.Windows.Data;
using System.Windows.Documents;
using System.Windows.Input;
using System.Windows.Media;
using System.Windows.Media.Imaging;
using System.Windows.Navigation;
using System.Windows.Shapes;
using MindFusion.Charting.Wpf;
using System.Windows.Media.Media3D;

namespace Demo
{
	/// <summary>
	/// Interaction logic for SurfaceTypes.xaml
	/// </summary>
	public partial class SurfaceTypes : UserControl
	{
        BrushCollection brushes = Utilities.GetGradientFills();
        BrushCollection strokes = Utilities.GetGradientStrokes();
        Brush stroke = null;
        Brush brush = new SolidColorBrush(Color.FromArgb(255, Brushes.LightBlue.Color.R,
            Brushes.LightBlue.Color.G, Brushes.LightBlue.Color.B));

		public SurfaceTypes()
		{
			InitializeComponent();

            System.Windows.Controls.Grid.SetZIndex(surfaceChart, -1);
            brush = brushes[7];
            stroke = strokes[7];

			surfaceChart.Title = "";
			//surfaceChart.XAxisSettings.Title = "";
            surfaceChart.XAxisSettings.TitleStroke = Brushes.White;
            surfaceChart.XAxisSettings.Title = "Width";
			surfaceChart.XAxisSettings.LabelFormat = "0.##";
            surfaceChart.XAxisSettings.TitleOffset = 5;
            surfaceChart.XAxisSettings.TitleFontSize = 12;
            surfaceChart.XAxisSettings.LabelFontSize = 12;
            surfaceChart.XAxisSettings.LabelOffset = 3;
			//surfaceChart.YAxisSettings.Title = "";
            surfaceChart.YAxisSettings.TitleStroke = Brushes.White;
            surfaceChart.YAxisSettings.Title = "Height";
            surfaceChart.YAxisSettings.LabelFormat = "0.##";
			surfaceChart.ZAxisSettings.LabelType = LabelType.Empty;
            surfaceChart.YAxisSettings.TitleOffset = 5;
            surfaceChart.YAxisSettings.TitleFontSize = 12;
            surfaceChart.YAxisSettings.LabelFontSize = 12;
            surfaceChart.YAxisSettings.LabelOffset = 3;

            surfaceChart.MeshFaceSize = 2.0;
            surfaceChart.InterpolationSensitivity = 30;
            surfaceChart.GridFills = new List<Brush>();
            surfaceChart.GridStrokes = new List<Brush>();
			//surfaceChart.ShowColorMap = true;
			//surfaceChart.GradientColorMap = false;

			if (slider != null)
                slider.Value = surfaceChart.InterpolationSensitivity;
			//if (textureType != null)
			//	textureType.SelectedIndex = 1;

			//surfaceChart.GridType = GridType.Crossed;


            surfaceChart.XAxisSettings.MinValue = 0;
            surfaceChart.XAxisSettings.MaxValue = 30;
            surfaceChart.YAxisSettings.MinValue = -10;
            surfaceChart.YAxisSettings.MaxValue = 10;
            surfaceChart.ZAxisSettings.MinValue = 0;
            surfaceChart.ZAxisSettings.MaxValue = 30;


            surfaceChart.ModelWidth = 60;
            surfaceChart.ModelHeight = 40;
            surfaceChart.ModelDepth = 60;        

            surfaceChart.GroundLevel = 0;
            surfaceChart.SideWallThickness = 0.5;
            surfaceChart.Effect3D = ChartEffect3D.ShaderEffect;
            surfaceChart.Scale = 185;
            surfaceChart.XAxisSettings.LabelStroke = Brushes.White;
            surfaceChart.YAxisSettings.LabelStroke = Brushes.White;

            //DirectionalLight light = new DirectionalLight()
            //{
            //    Color = Colors.White,
            //    Direction = new Vector3D(-1, 3, -1),
            //};

            //surfaceChart.StaticLights.Add(light);

            SurfaceSeries series = new SurfaceSeries();
            series.XData = new DoubleCollection() { 15, 20, 20, 8 };
            series.YData = new DoubleCollection() { 7, 8.5, -5, 9.5 };
            series.ZData = new DoubleCollection() { 15, 10, 20, 23 };
            series.Fills.Add(brush);
            series.Strokes.Add(stroke);
            surfaceChart.Series.Add(series);


            //RandomData();
		}       

        private void RandomData()
        {
            Random r = new Random();
            DoubleCollection dx = new DoubleCollection();
            DoubleCollection dy = new DoubleCollection();
            DoubleCollection dz = new DoubleCollection();
            for (int i = 0; i < 10; i++)
            {
                dx.Add((r.NextDouble() / 2) * 30);
                dy.Add((r.NextDouble() / 2 + 0.5) * 10);
                dz.Add(r.NextDouble() * 30);
            }
            for (int i = 0; i < 10; i++)
            {
                dx.Add((r.NextDouble() / 2 + 0.5) * 30);
                dy.Add((-(r.NextDouble() / 2 + 0.5)) * 10);
                dz.Add(r.NextDouble() * 30);
            }

        


            foreach (SurfaceSeries s in surfaceChart.Series)
            {
                s.XData.Clear();
                s.YData.Clear();
                s.ZData.Clear();

                s.XData = dx.Clone();
                s.YData = dy.Clone();
                s.ZData = dz.Clone();
            }
        }

		private void surfaceType_SelectionChanged(object sender, SelectionChangedEventArgs e)
		{
			if (surfaceChart == null)
				return;

            if (surfaceType.SelectedIndex == 0)
            {
                surfaceChart.ShowWireFrame = true;
                surfaceChart.ShowSurface = false;
            }
            if (surfaceType.SelectedIndex == 1)
            {
                surfaceChart.ShowWireFrame = false;
                surfaceChart.ShowSurface = true;
            }
            if (surfaceType.SelectedIndex == 2)
            {
                surfaceChart.ShowWireFrame = true;
                surfaceChart.ShowSurface = true;
            }

            if (textureType.SelectedIndex == 1)
            {
                if (surfaceType.SelectedIndex == 0)
                    surfaceChart.TextureType = TextureType.Brush;
                else
                    surfaceChart.TextureType = TextureType.GradientColorMap;
            }

            surfaceChart.UpdateChart();
		}

		private void textureType_SelectionChanged(object sender, SelectionChangedEventArgs e)
		{
			if (surfaceChart == null)
				return;

            if (textureType.SelectedIndex == 0)
            {
                surfaceChart.TextureType = TextureType.Brush;
            }
            if (textureType.SelectedIndex == 1)
            {
                surfaceChart.TextureType = TextureType.GradientColorMap;
            }
		}

		private void shape_SelectionChanged(object sender, SelectionChangedEventArgs e)
		{
			if (surfaceChart == null)
				return;

			surfaceChart.Effect3D = shape.SelectedIndex == 0 ?
                    ChartEffect3D.None : ChartEffect3D.ShaderEffect;
		}

		private void Slider_ValueChanged(object sender, RoutedPropertyChangedEventArgs<double> e)
		{
			if (surfaceChart == null)
				return;
			
            surfaceChart.InterpolationSensitivity = e.NewValue;
		}

		private void lightType_SelectionChanged(object sender, SelectionChangedEventArgs e)
		{
			if (surfaceChart == null)
				return;

            if (lightType.SelectedIndex == 0)
            {
                surfaceChart.Lights.Clear();
                DirectionalLight light = new DirectionalLight()
                {
                    Color = Colors.White,
                    Direction = new Vector3D(0, 0, -40),
                };
                surfaceChart.Lights.Add(light);
            }
            else
            {
                surfaceChart.Lights.Clear();
                AmbientLight light = new AmbientLight()
                {
                    Color = Colors.White,                    
                };
                surfaceChart.Lights.Add(light);
            }		
		}

		private void cameraType_SelectionChanged(object sender, SelectionChangedEventArgs e)
		{
			if (surfaceChart == null)
				return;

			surfaceChart.CameraType = cameraType.SelectedIndex == 0 ?
					CameraType.Perspective : CameraType.Orthographic;
		}

		double scaleBuffer = 0;

        private void Border_SizeChanged(object sender, SizeChangedEventArgs e)
        {
            Window1.OnBackPanelSizeChanged(sender);
        }

        private void ComboBox_DropDownOpened(object sender, EventArgs e)
        {
            ((sender as ComboBox).Items[0] as ComboBoxItem).Visibility = Visibility.Collapsed;
        }

        private void ComboBox_DropDownClosed(object sender, EventArgs e)
        {
            ((sender as ComboBox).Items[0] as ComboBoxItem).Visibility = Visibility.Visible;
        }
	}
}
