﻿using System;
using System.Collections.Generic;
using System.Linq;
using System.Text;
using System.Windows;
using System.Windows.Controls;
using System.Windows.Data;
using System.Windows.Documents;
using System.Windows.Input;
using System.Windows.Media;
using System.Windows.Media.Imaging;
using System.Windows.Navigation;
using System.Windows.Shapes;
using MindFusion.Charting.Wpf;
using System.Windows.Media.Animation;
using System.Reflection;
using System.Xml;
using System.Windows.Media.Effects;

namespace Demo
{
    /// <summary>
    /// Interaction logic for Window1.xaml
    /// </summary>
    public partial class Window1 : Window
    {
        private static Storyboard storyboard = new Storyboard();
        private UserControl currentControl;
        private UserControl lastControl;
        private double duration = 1;
        private double coef = 0.3;
        private DropShadowEffect effect;

        public Window1()
        {
            InitializeComponent();
            effect = new DropShadowEffect() { Opacity = 0.3, ShadowDepth = 3, };
            effect.Freeze();

            _treeView.Effect = effect;
            titleText.Effect = effect;
            descriptionText.Effect = effect;

            _treeView.SelectedItemChanged += new RoutedPropertyChangedEventHandler<object>(OnTreeViewSelectedItemChanged);
        }

        private void OnTreeViewSelectedItemChanged(object sender, RoutedPropertyChangedEventArgs<object> e)
        {
            Type[] types = Assembly.GetExecutingAssembly().GetTypes();
            XmlElement item = _treeView.SelectedItem as XmlElement;
            if (item.Name == "MenuItem" || item.Name == "SubMenuItem")
            {

                string[] str = item.OuterXml.Split(' ');
                for (int i = 0; i < str.Length; i++)
                {
                    string s = str[i];
                    if (s.StartsWith("File"))
                    {
                        List<char> chars = new List<char>();
                        for (int j = 6; j < s.Length - 6; j++)
                            chars.Add(s[j]);
                        string tempString = new string(chars.ToArray());

                        foreach (Type t in types)
                        {
                            if (t.Name == tempString)
                            {
                                lastControl = currentControl;
                                if (lastControl != null)
                                    HideControl(lastControl);

                                UserControl control = t.GetConstructor(Type.EmptyTypes).Invoke(null) as UserControl;
                                control.Opacity = 0;
                                contentGrid.Children.Add(control);
                                UpdateLayout();
                                currentControl = control;
                                ShowControl(currentControl);


                                for (int l = contentGrid.Children.Count - 1; l >= 0; l--)
                                {
                                    if (contentGrid.Children[l] != currentControl && 
                                        contentGrid.Children[l] != lastControl)
                                    {
                                        contentGrid.Children.Remove(contentGrid.Children[l]);
                                    }
                                }
                            }
                        }
                    }
                }
            }
            else
            {
                lastControl = currentControl;
                if (lastControl != null)
                    HideControl(lastControl);

                currentControl = null;
            }
        }

        internal static VisualBrush TransformBrush(Brush transBrush, double opacity)
        {
            LinearGradientBrush b = transBrush as LinearGradientBrush;
            Color light = b.GradientStops[0].Color;
            Color dark = b.GradientStops[1].Color;
            VisualBrush brush = Utilities.CreateVisualBrush(
                dark, light, new SolidColorBrush(dark), 0, Orientation.Horizontal, 0);
            brush.Opacity = opacity;
            return brush;
        }

        private void HideControl(UserControl control)
        {
            double width = control.ActualWidth;

            DoubleAnimation doubleAnimation = new DoubleAnimation();
            doubleAnimation.From = 1.0;
            doubleAnimation.To = 0.0;
            doubleAnimation.Duration = new Duration(TimeSpan.FromSeconds(duration));
            doubleAnimation.DecelerationRatio = coef;
            doubleAnimation.AccelerationRatio = coef;
            control.BeginAnimation(UserControl.OpacityProperty, doubleAnimation);

            ThicknessAnimation tAnimation = new ThicknessAnimation();
            tAnimation.From = new Thickness(0, 0, 0, 0);
            tAnimation.To = new Thickness(width, 0, -width, 0);
            tAnimation.Duration = new Duration(TimeSpan.FromSeconds(duration));
            tAnimation.DecelerationRatio = coef;
            tAnimation.AccelerationRatio = coef;
            tAnimation.Completed += new EventHandler(tAnimation_Completed);
            control.BeginAnimation(UserControl.MarginProperty, tAnimation);
        }

        private void ControlBorder_SizeChanged(object sender, SizeChangedEventArgs e)
        {
           
        }

        private void tAnimation_Completed(object sender, EventArgs e)
        {
            contentGrid.Children.Remove(sender as UserControl);           
        }

        private void ShowControl(UserControl control)
        {
            double width = control.ActualWidth;

            DoubleAnimation doubleAnimation = new DoubleAnimation();
            doubleAnimation.From = 0.0;
            doubleAnimation.To = 1.0;
            doubleAnimation.Duration = new Duration(TimeSpan.FromSeconds(duration));
            doubleAnimation.DecelerationRatio = coef;
            doubleAnimation.AccelerationRatio = coef;
            control.BeginAnimation(UserControl.OpacityProperty, doubleAnimation);

            ThicknessAnimation tAnimation = new ThicknessAnimation();
            tAnimation.From = new Thickness(-width, 0, width, 0);
            tAnimation.To = new Thickness(0, 0, 0, 0);
            tAnimation.Duration = new Duration(TimeSpan.FromSeconds(duration));
            tAnimation.DecelerationRatio = coef;
            tAnimation.AccelerationRatio = coef;
            control.BeginAnimation(UserControl.MarginProperty, tAnimation);
        }     

        internal static VisualBrush GetPanelBrush(double opasity)
        {
            VisualBrush visualBrush = Utilities.CreateVisualBrush(Color.FromRgb(23, 49, 70),
                Color.FromRgb(58, 124, 175), new SolidColorBrush(Color.FromRgb(0, 56, 81)), 4,
                Orientation.Horizontal, 10);

            //BrushCollection brushes = Utilities.GetGradientFills();
            //LinearGradientBrush b = brushes[brushes.Count - 1] as LinearGradientBrush;
            //Color light = b.GradientStops[0].Color;
            //Color dark = b.GradientStops[1].Color;
            //VisualBrush visualBrush = Utilities.CreateVisualBrush(
            //    dark, light, new SolidColorBrush(dark), 4, Orientation.Horizontal, 10);
            visualBrush.Opacity = opasity;
            return visualBrush;
        }

        internal static void OnBackPanelSizeChanged(object sender)
        {
            VisualBrush visualBrush = null;
            
            if (sender is Border)
            {
                Border border = sender as Border;
                if (border.Parent is UserControl && (border.Parent as UserControl).Tag != null)
                    return;

                if (border.Background == null || !(border.Background is VisualBrush))
                    border.Background = GetPanelBrush(0.7);
                visualBrush = border.Background as VisualBrush;
                FrameworkElement element = visualBrush.Visual as FrameworkElement;
                element.Width = border.ActualWidth;
                element.Height = border.ActualHeight;
                if (border.Parent is UserControl)
                {
                    (border.Parent as UserControl).Tag = border;
                }
            }
            if (sender is Button)
            {
                Button button = sender as Button;
                button.Focusable = false;
                if (button.Background == null || !(button.Background is VisualBrush))
                {
                    VisualBrush b = Utilities.CreateVisualBrush(Color.FromRgb(23, 49, 70),
                        Color.FromRgb(58, 124, 175), new SolidColorBrush(Color.FromRgb(0, 56, 81)), 4,
                        Orientation.Horizontal, 10,0);
                    //b.Opacity = 0.7;
                    button.Background = b;
                }
                visualBrush = button.Background as VisualBrush;
                FrameworkElement element = visualBrush.Visual as FrameworkElement;
                element.Width = button.ActualWidth;
                element.Height = button.ActualHeight;
            }
            if (sender is ComboBox)
            {
                ComboBox comboBox = sender as ComboBox;
                comboBox.Focusable = false;
                if (comboBox.Background == null || !(comboBox.Background is VisualBrush))
                    comboBox.Background = GetPanelBrush(0.7);
                visualBrush = comboBox.Background as VisualBrush;
                FrameworkElement element = visualBrush.Visual as FrameworkElement;
                element.Width = comboBox.ActualWidth;
                element.Height = comboBox.ActualHeight;
            }
            if (sender is SeriesLegend)
            {
                SeriesLegend legend = sender as SeriesLegend;

                if (legend.Background == null || !(legend.Background is VisualBrush))
                    legend.Background = GetPanelBrush(0.6);
                visualBrush = legend.Background as VisualBrush;
                FrameworkElement element = visualBrush.Visual as FrameworkElement;
                element.Width = legend.ActualWidth;
                element.Height = legend.ActualHeight;
            }
        }

        private void Border_SizeChanged(object sender, SizeChangedEventArgs e)
        {
            Window1.OnBackPanelSizeChanged(sender);
        }

        private void Border_SizeChanged_1(object sender, SizeChangedEventArgs e)
        {
            Window1.OnBackPanelSizeChanged(sender);
        }

        private void Border_SizeChanged_2(object sender, SizeChangedEventArgs e)
        {
            Window1.OnBackPanelSizeChanged(sender);
        }

        private void GridSplitter_MouseEnter(object sender, MouseEventArgs e)
        {
            (sender as GridSplitter).Background = new SolidColorBrush(Color.FromArgb(170,0, 56, 81));
        }

        private void GridSplitter_MouseLeave(object sender, MouseEventArgs e)
        {
            (sender as GridSplitter).Background = Brushes.Transparent;
        }   
    }
}
